'''OpenGL extension EXT.vertex_array

Overview (from the spec)
	
	This extension adds the ability to specify multiple geometric primitives
	with very few subroutine calls.  Instead of calling an OpenGL procedure
	to pass each individual vertex, normal, or color, separate arrays
	of vertexes, normals, and colors are prespecified, and are used to
	define a sequence of primitives (all of the same type) when a single
	call is made to DrawArraysEXT.  A stride mechanism is provided so that
	an application can choose to keep all vertex data staggered in a
	single array, or sparsely in separate arrays.  Single-array storage
	may optimize performance on some implementations.
	
	This extension also supports the rendering of individual array elements,
	each specified as an index into the enabled arrays.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/vertex_array.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_vertex_array'
GL_VERTEX_ARRAY_EXT = constant.Constant( 'GL_VERTEX_ARRAY_EXT', 0x8074 )
GL_NORMAL_ARRAY_EXT = constant.Constant( 'GL_NORMAL_ARRAY_EXT', 0x8075 )
GL_COLOR_ARRAY_EXT = constant.Constant( 'GL_COLOR_ARRAY_EXT', 0x8076 )
GL_INDEX_ARRAY_EXT = constant.Constant( 'GL_INDEX_ARRAY_EXT', 0x8077 )
GL_TEXTURE_COORD_ARRAY_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_EXT', 0x8078 )
GL_EDGE_FLAG_ARRAY_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_EXT', 0x8079 )
GL_VERTEX_ARRAY_SIZE_EXT = constant.Constant( 'GL_VERTEX_ARRAY_SIZE_EXT', 0x807A )
glget.addGLGetConstant( GL_VERTEX_ARRAY_SIZE_EXT, (1,) )
GL_VERTEX_ARRAY_TYPE_EXT = constant.Constant( 'GL_VERTEX_ARRAY_TYPE_EXT', 0x807B )
glget.addGLGetConstant( GL_VERTEX_ARRAY_TYPE_EXT, (1,) )
GL_VERTEX_ARRAY_STRIDE_EXT = constant.Constant( 'GL_VERTEX_ARRAY_STRIDE_EXT', 0x807C )
glget.addGLGetConstant( GL_VERTEX_ARRAY_STRIDE_EXT, (1,) )
GL_VERTEX_ARRAY_COUNT_EXT = constant.Constant( 'GL_VERTEX_ARRAY_COUNT_EXT', 0x807D )
glget.addGLGetConstant( GL_VERTEX_ARRAY_COUNT_EXT, (1,) )
GL_NORMAL_ARRAY_TYPE_EXT = constant.Constant( 'GL_NORMAL_ARRAY_TYPE_EXT', 0x807E )
glget.addGLGetConstant( GL_NORMAL_ARRAY_TYPE_EXT, (1,) )
GL_NORMAL_ARRAY_STRIDE_EXT = constant.Constant( 'GL_NORMAL_ARRAY_STRIDE_EXT', 0x807F )
glget.addGLGetConstant( GL_NORMAL_ARRAY_STRIDE_EXT, (1,) )
GL_NORMAL_ARRAY_COUNT_EXT = constant.Constant( 'GL_NORMAL_ARRAY_COUNT_EXT', 0x8080 )
glget.addGLGetConstant( GL_NORMAL_ARRAY_COUNT_EXT, (1,) )
GL_COLOR_ARRAY_SIZE_EXT = constant.Constant( 'GL_COLOR_ARRAY_SIZE_EXT', 0x8081 )
glget.addGLGetConstant( GL_COLOR_ARRAY_SIZE_EXT, (1,) )
GL_COLOR_ARRAY_TYPE_EXT = constant.Constant( 'GL_COLOR_ARRAY_TYPE_EXT', 0x8082 )
glget.addGLGetConstant( GL_COLOR_ARRAY_TYPE_EXT, (1,) )
GL_COLOR_ARRAY_STRIDE_EXT = constant.Constant( 'GL_COLOR_ARRAY_STRIDE_EXT', 0x8083 )
glget.addGLGetConstant( GL_COLOR_ARRAY_STRIDE_EXT, (1,) )
GL_COLOR_ARRAY_COUNT_EXT = constant.Constant( 'GL_COLOR_ARRAY_COUNT_EXT', 0x8084 )
glget.addGLGetConstant( GL_COLOR_ARRAY_COUNT_EXT, (1,) )
GL_INDEX_ARRAY_TYPE_EXT = constant.Constant( 'GL_INDEX_ARRAY_TYPE_EXT', 0x8085 )
glget.addGLGetConstant( GL_INDEX_ARRAY_TYPE_EXT, (1,) )
GL_INDEX_ARRAY_STRIDE_EXT = constant.Constant( 'GL_INDEX_ARRAY_STRIDE_EXT', 0x8086 )
glget.addGLGetConstant( GL_INDEX_ARRAY_STRIDE_EXT, (1,) )
GL_INDEX_ARRAY_COUNT_EXT = constant.Constant( 'GL_INDEX_ARRAY_COUNT_EXT', 0x8087 )
glget.addGLGetConstant( GL_INDEX_ARRAY_COUNT_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_SIZE_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_SIZE_EXT', 0x8088 )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_SIZE_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_TYPE_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_TYPE_EXT', 0x8089 )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_TYPE_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_STRIDE_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT', 0x808A )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_STRIDE_EXT, (1,) )
GL_TEXTURE_COORD_ARRAY_COUNT_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_COUNT_EXT', 0x808B )
glget.addGLGetConstant( GL_TEXTURE_COORD_ARRAY_COUNT_EXT, (1,) )
GL_EDGE_FLAG_ARRAY_STRIDE_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_STRIDE_EXT', 0x808C )
glget.addGLGetConstant( GL_EDGE_FLAG_ARRAY_STRIDE_EXT, (1,) )
GL_EDGE_FLAG_ARRAY_COUNT_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_COUNT_EXT', 0x808D )
glget.addGLGetConstant( GL_EDGE_FLAG_ARRAY_COUNT_EXT, (1,) )
GL_VERTEX_ARRAY_POINTER_EXT = constant.Constant( 'GL_VERTEX_ARRAY_POINTER_EXT', 0x808E )
GL_NORMAL_ARRAY_POINTER_EXT = constant.Constant( 'GL_NORMAL_ARRAY_POINTER_EXT', 0x808F )
GL_COLOR_ARRAY_POINTER_EXT = constant.Constant( 'GL_COLOR_ARRAY_POINTER_EXT', 0x8090 )
GL_INDEX_ARRAY_POINTER_EXT = constant.Constant( 'GL_INDEX_ARRAY_POINTER_EXT', 0x8091 )
GL_TEXTURE_COORD_ARRAY_POINTER_EXT = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_POINTER_EXT', 0x8092 )
GL_EDGE_FLAG_ARRAY_POINTER_EXT = constant.Constant( 'GL_EDGE_FLAG_ARRAY_POINTER_EXT', 0x8093 )
glArrayElementEXT = platform.createExtensionFunction( 
	'glArrayElementEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLint,),
	doc = 'glArrayElementEXT( GLint(i) ) -> None',
	argNames = ('i',),
)

glColorPointerEXT = platform.createExtensionFunction( 
	'glColorPointerEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glColorPointerEXT( GLint(size), GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer) ) -> None',
	argNames = ('size', 'type', 'stride', 'count', 'pointer',),
)

glDrawArraysEXT = platform.createExtensionFunction( 
	'glDrawArraysEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLsizei,),
	doc = 'glDrawArraysEXT( GLenum(mode), GLint(first), GLsizei(count) ) -> None',
	argNames = ('mode', 'first', 'count',),
)

glEdgeFlagPointerEXT = platform.createExtensionFunction( 
	'glEdgeFlagPointerEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLsizei, constants.GLsizei, ctypes.POINTER(constants.GLboolean),),
	doc = 'glEdgeFlagPointerEXT( GLsizei(stride), GLsizei(count), POINTER(constants.GLboolean)(pointer) ) -> None',
	argNames = ('stride', 'count', 'pointer',),
)

glGetPointervEXT = platform.createExtensionFunction( 
	'glGetPointervEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, ctypes.POINTER(ctypes.c_void_p),),
	doc = 'glGetPointervEXT( GLenum(pname), POINTER(ctypes.c_void_p)(params) ) -> None',
	argNames = ('pname', 'params',),
)

glIndexPointerEXT = platform.createExtensionFunction( 
	'glIndexPointerEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLsizei, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glIndexPointerEXT( GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer) ) -> None',
	argNames = ('type', 'stride', 'count', 'pointer',),
)

glNormalPointerEXT = platform.createExtensionFunction( 
	'glNormalPointerEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLsizei, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glNormalPointerEXT( GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer) ) -> None',
	argNames = ('type', 'stride', 'count', 'pointer',),
)

glTexCoordPointerEXT = platform.createExtensionFunction( 
	'glTexCoordPointerEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glTexCoordPointerEXT( GLint(size), GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer) ) -> None',
	argNames = ('size', 'type', 'stride', 'count', 'pointer',),
)

glVertexPointerEXT = platform.createExtensionFunction( 
	'glVertexPointerEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glVertexPointerEXT( GLint(size), GLenum(type), GLsizei(stride), GLsizei(count), c_void_p(pointer) ) -> None',
	argNames = ('size', 'type', 'stride', 'count', 'pointer',),
)


def glInitVertexArrayEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.vertex_attrib_array_object

Overview (from the spec)
	
	This extension defines an interface that allows multiple sets of
	generic vertex attribute data to be cached in persistent server-side
	memory.  It is intended to allow client data to be stored in memory
	that can be directly accessed by graphics hardware.
	

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ATI/vertex_attrib_array_object.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_vertex_attrib_array_object'

glVertexAttribArrayObjectATI = platform.createExtensionFunction( 
	'glVertexAttribArrayObjectATI', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint, constants.GLenum, constants.GLboolean, constants.GLsizei, constants.GLuint, constants.GLuint,),
	doc = 'glVertexAttribArrayObjectATI( GLuint(index), GLint(size), GLenum(type), GLboolean(normalized), GLsizei(stride), GLuint(buffer), GLuint(offset) ) -> None',
	argNames = ('index', 'size', 'type', 'normalized', 'stride', 'buffer', 'offset',),
)

glGetVertexAttribArrayObjectfvATI = platform.createExtensionFunction( 
	'glGetVertexAttribArrayObjectfvATI', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetVertexAttribArrayObjectfvATI( GLuint(index), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribArrayObjectivATI = platform.createExtensionFunction( 
	'glGetVertexAttribArrayObjectivATI', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetVertexAttribArrayObjectivATI( GLuint(index), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)


def glInitVertexAttribArrayObjectATI():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.shadow

Overview (from the spec)
	
	This extension defines two new operations to be performed on texture
	values before they are passed on to the filtering subsystem.  These
	operations perform either a <= or >= test on the value from texture
	memory and the iterated R value, and return 1.0 or 0.0 if the test
	passes or fails, respectively.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SGIX/shadow.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_shadow'
GL_TEXTURE_COMPARE_SGIX = constant.Constant( 'GL_TEXTURE_COMPARE_SGIX', 0x819A )
GL_TEXTURE_COMPARE_OPERATOR_SGIX = constant.Constant( 'GL_TEXTURE_COMPARE_OPERATOR_SGIX', 0x819B )
GL_TEXTURE_LEQUAL_R_SGIX = constant.Constant( 'GL_TEXTURE_LEQUAL_R_SGIX', 0x819C )
GL_TEXTURE_GEQUAL_R_SGIX = constant.Constant( 'GL_TEXTURE_GEQUAL_R_SGIX', 0x819D )


def glInitShadowSGIX():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension APPLE.flush_buffer_range

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/APPLE/flush_buffer_range.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_APPLE_flush_buffer_range'
GL_BUFFER_SERIALIZED_MODIFY_APPLE = constant.Constant( 'GL_BUFFER_SERIALIZED_MODIFY_APPLE', 0x8A12 )
GL_BUFFER_FLUSHING_UNMAP_APPLE = constant.Constant( 'GL_BUFFER_FLUSHING_UNMAP_APPLE', 0x8A13 )
glBufferParameteriAPPLE = platform.createExtensionFunction( 
	'glBufferParameteriAPPLE', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint,),
	doc = 'glBufferParameteriAPPLE( GLenum(target), GLenum(pname), GLint(param) ) -> None',
	argNames = ('target', 'pname', 'param',),
)

glFlushMappedBufferRangeAPPLE = platform.createExtensionFunction( 
	'glFlushMappedBufferRangeAPPLE', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLintptr, constants.GLsizeiptr,),
	doc = 'glFlushMappedBufferRangeAPPLE( GLenum(target), GLintptr(offset), GLsizeiptr(size) ) -> None',
	argNames = ('target', 'offset', 'size',),
)


def glInitFlushBufferRangeAPPLE():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_non_power_of_two

Overview (from the spec)
	
	Conventional OpenGL texturing is limited to images with
	power-of-two dimensions and an optional 1-texel border.
	ARB_texture_non_power_of_two extension relaxes the size restrictions
	for the 1D, 2D, cube map, and 3D texture targets.
	
	There is no additional procedural or enumerant api introduced by this
	extension except that an implementation which exports the extension
	string will allow an application to pass in texture dimensions for
	the 1D, 2D, cube map, and 3D targets that may or may not be a power
	of two.
	
	An implementation which supports relaxing traditional GL's
	power-of-two size restrictions across all texture targets will export
	the extension string: "ARB_texture_non_power_of_two".
	
	When this extension is supported, mipmapping, automatic mipmap
	generation, and all the conventional wrap modes are supported for
	non-power-of-two textures

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_non_power_of_two.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_non_power_of_two'



def glInitTextureNonPowerOfTwoARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.multisample_filter_hint

Overview (from the spec)
	
	OpenGL multisampling typically assumes that the samples of a given
	pixel are weighted uniformly and averaged to compute the pixel's
	resolved color.  This extension provides a hint that permits
	implementations to provide an alternative method of resolving the
	color of multisampled pixels.
	
	As an example of such an alternative method, NVIDIA's GeForce3 GPU
	provides a technique known as Quincunx filtering.  This technique
	is used in two-sample multisampling, but it blends the pixel's two
	samples and three additional samples from adjacent pixels.  The sample
	pattern is analogous to the 5 pattern on a die.  The quality of this
	technique is widely regarded as comparable to 4 sample multisampling.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/multisample_filter_hint.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_multisample_filter_hint'
GL_MULTISAMPLE_FILTER_HINT_NV = constant.Constant( 'GL_MULTISAMPLE_FILTER_HINT_NV', 0x8534 )
glget.addGLGetConstant( GL_MULTISAMPLE_FILTER_HINT_NV, (1,) )


def glInitMultisampleFilterHintNV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension IBM.texture_mirrored_repeat

Overview (from the spec)
	
	IBM_texture_mirrored_repeat extends the set of texture wrap modes to
	include a mode (GL_MIRRORED_REPEAT_IBM) that effectively uses a texture
	map twice as large at the original image in which the additional half of
	the new image is a mirror image of the original image.
	
	This new mode relaxes the need to generate images whose opposite edges
	match by using the original image to generate a matching "mirror image".

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/IBM/texture_mirrored_repeat.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_texture_mirrored_repeat'
GL_MIRRORED_REPEAT_IBM = constant.Constant( 'GL_MIRRORED_REPEAT_IBM', 0x8370 )


def glInitTextureMirroredRepeatIBM():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.convolution

Overview (from the spec)
	
	This extension defines 1 and 2 dimensional convolution operations
	at a fixed location in the pixel transfer process.  Thus pixel drawing,
	reading, and copying, as well as texture image definition, are all
	candidates for convolution.  The convolution kernels are themselves
	treated as 1 and 2 dimensional images, which can be loaded from
	application memory or from the framebuffer.
	
	This extension is designed to accommodate 3D convolution, but the
	API is left for a future extension.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/convolution.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_convolution'
GL_CONVOLUTION_1D_EXT = constant.Constant( 'GL_CONVOLUTION_1D_EXT', 0x8010 )
glget.addGLGetConstant( GL_CONVOLUTION_1D_EXT, (1,) )
GL_CONVOLUTION_2D_EXT = constant.Constant( 'GL_CONVOLUTION_2D_EXT', 0x8011 )
glget.addGLGetConstant( GL_CONVOLUTION_2D_EXT, (1,) )
GL_SEPARABLE_2D_EXT = constant.Constant( 'GL_SEPARABLE_2D_EXT', 0x8012 )
glget.addGLGetConstant( GL_SEPARABLE_2D_EXT, (1,) )
GL_CONVOLUTION_BORDER_MODE_EXT = constant.Constant( 'GL_CONVOLUTION_BORDER_MODE_EXT', 0x8013 )
GL_CONVOLUTION_FILTER_SCALE_EXT = constant.Constant( 'GL_CONVOLUTION_FILTER_SCALE_EXT', 0x8014 )
GL_CONVOLUTION_FILTER_BIAS_EXT = constant.Constant( 'GL_CONVOLUTION_FILTER_BIAS_EXT', 0x8015 )
GL_REDUCE_EXT = constant.Constant( 'GL_REDUCE_EXT', 0x8016 )
GL_CONVOLUTION_FORMAT_EXT = constant.Constant( 'GL_CONVOLUTION_FORMAT_EXT', 0x8017 )
GL_CONVOLUTION_WIDTH_EXT = constant.Constant( 'GL_CONVOLUTION_WIDTH_EXT', 0x8018 )
GL_CONVOLUTION_HEIGHT_EXT = constant.Constant( 'GL_CONVOLUTION_HEIGHT_EXT', 0x8019 )
GL_MAX_CONVOLUTION_WIDTH_EXT = constant.Constant( 'GL_MAX_CONVOLUTION_WIDTH_EXT', 0x801A )
GL_MAX_CONVOLUTION_HEIGHT_EXT = constant.Constant( 'GL_MAX_CONVOLUTION_HEIGHT_EXT', 0x801B )
GL_POST_CONVOLUTION_RED_SCALE_EXT = constant.Constant( 'GL_POST_CONVOLUTION_RED_SCALE_EXT', 0x801C )
glget.addGLGetConstant( GL_POST_CONVOLUTION_RED_SCALE_EXT, (1,) )
GL_POST_CONVOLUTION_GREEN_SCALE_EXT = constant.Constant( 'GL_POST_CONVOLUTION_GREEN_SCALE_EXT', 0x801D )
glget.addGLGetConstant( GL_POST_CONVOLUTION_GREEN_SCALE_EXT, (1,) )
GL_POST_CONVOLUTION_BLUE_SCALE_EXT = constant.Constant( 'GL_POST_CONVOLUTION_BLUE_SCALE_EXT', 0x801E )
glget.addGLGetConstant( GL_POST_CONVOLUTION_BLUE_SCALE_EXT, (1,) )
GL_POST_CONVOLUTION_ALPHA_SCALE_EXT = constant.Constant( 'GL_POST_CONVOLUTION_ALPHA_SCALE_EXT', 0x801F )
glget.addGLGetConstant( GL_POST_CONVOLUTION_ALPHA_SCALE_EXT, (1,) )
GL_POST_CONVOLUTION_RED_BIAS_EXT = constant.Constant( 'GL_POST_CONVOLUTION_RED_BIAS_EXT', 0x8020 )
glget.addGLGetConstant( GL_POST_CONVOLUTION_RED_BIAS_EXT, (1,) )
GL_POST_CONVOLUTION_GREEN_BIAS_EXT = constant.Constant( 'GL_POST_CONVOLUTION_GREEN_BIAS_EXT', 0x8021 )
glget.addGLGetConstant( GL_POST_CONVOLUTION_GREEN_BIAS_EXT, (1,) )
GL_POST_CONVOLUTION_BLUE_BIAS_EXT = constant.Constant( 'GL_POST_CONVOLUTION_BLUE_BIAS_EXT', 0x8022 )
glget.addGLGetConstant( GL_POST_CONVOLUTION_BLUE_BIAS_EXT, (1,) )
GL_POST_CONVOLUTION_ALPHA_BIAS_EXT = constant.Constant( 'GL_POST_CONVOLUTION_ALPHA_BIAS_EXT', 0x8023 )
glget.addGLGetConstant( GL_POST_CONVOLUTION_ALPHA_BIAS_EXT, (1,) )
glConvolutionFilter1DEXT = platform.createExtensionFunction( 
	'glConvolutionFilter1DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glConvolutionFilter1DEXT( GLenum(target), GLenum(internalformat), GLsizei(width), GLenum(format), GLenum(type), c_void_p(image) ) -> None',
	argNames = ('target', 'internalformat', 'width', 'format', 'type', 'image',),
)

glConvolutionFilter2DEXT = platform.createExtensionFunction( 
	'glConvolutionFilter2DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glConvolutionFilter2DEXT( GLenum(target), GLenum(internalformat), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(image) ) -> None',
	argNames = ('target', 'internalformat', 'width', 'height', 'format', 'type', 'image',),
)

glConvolutionParameterfEXT = platform.createExtensionFunction( 
	'glConvolutionParameterfEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLfloat,),
	doc = 'glConvolutionParameterfEXT( GLenum(target), GLenum(pname), GLfloat(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glConvolutionParameterfvEXT = platform.createExtensionFunction( 
	'glConvolutionParameterfvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glConvolutionParameterfvEXT( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glConvolutionParameteriEXT = platform.createExtensionFunction( 
	'glConvolutionParameteriEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint,),
	doc = 'glConvolutionParameteriEXT( GLenum(target), GLenum(pname), GLint(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glConvolutionParameterivEXT = platform.createExtensionFunction( 
	'glConvolutionParameterivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glConvolutionParameterivEXT( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glCopyConvolutionFilter1DEXT = platform.createExtensionFunction( 
	'glCopyConvolutionFilter1DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei,),
	doc = 'glCopyConvolutionFilter1DEXT( GLenum(target), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width) ) -> None',
	argNames = ('target', 'internalformat', 'x', 'y', 'width',),
)

glCopyConvolutionFilter2DEXT = platform.createExtensionFunction( 
	'glCopyConvolutionFilter2DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei,),
	doc = 'glCopyConvolutionFilter2DEXT( GLenum(target), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height) ) -> None',
	argNames = ('target', 'internalformat', 'x', 'y', 'width', 'height',),
)

glGetConvolutionFilterEXT = platform.createExtensionFunction( 
	'glGetConvolutionFilterEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glGetConvolutionFilterEXT( GLenum(target), GLenum(format), GLenum(type), c_void_p(image) ) -> None',
	argNames = ('target', 'format', 'type', 'image',),
)

glGetConvolutionParameterfvEXT = platform.createExtensionFunction( 
	'glGetConvolutionParameterfvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetConvolutionParameterfvEXT( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetConvolutionParameterivEXT = platform.createExtensionFunction( 
	'glGetConvolutionParameterivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetConvolutionParameterivEXT( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetSeparableFilterEXT = platform.createExtensionFunction( 
	'glGetSeparableFilterEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLenum, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p,),
	doc = 'glGetSeparableFilterEXT( GLenum(target), GLenum(format), GLenum(type), c_void_p(row), c_void_p(column), c_void_p(span) ) -> None',
	argNames = ('target', 'format', 'type', 'row', 'column', 'span',),
)

glSeparableFilter2DEXT = platform.createExtensionFunction( 
	'glSeparableFilter2DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p, ctypes.c_void_p,),
	doc = 'glSeparableFilter2DEXT( GLenum(target), GLenum(internalformat), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(row), c_void_p(column) ) -> None',
	argNames = ('target', 'internalformat', 'width', 'height', 'format', 'type', 'row', 'column',),
)


def glInitConvolutionEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_env_dot3

Overview (from the spec)
	
	Adds new operation to the texture combiner operations.
	
	    DOT3_RGB_EXT                    Arg0 <dotprod> Arg1
	    DOT3_RGBA_EXT                   Arg0 <dotprod> Arg1
	
	where Arg0, Arg1 are derived from
	
	    PRIMARY_COLOR_EXT       primary color of incoming fragment
	    TEXTURE                 texture color of corresponding texture unit
	    CONSTANT_EXT            texture environment constant color
	    PREVIOUS_EXT            result of previous texture environment; on
	                            texture unit 0, this maps to PRIMARY_COLOR_EXT
	
	This operaion can only be performed if SOURCE0_RGB_EXT,
	SOURCE1_RGB_EXT are defined.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/texture_env_dot3.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_env_dot3'
GL_DOT3_RGB_EXT = constant.Constant( 'GL_DOT3_RGB_EXT', 0x8740 )
GL_DOT3_RGBA_EXT = constant.Constant( 'GL_DOT3_RGBA_EXT', 0x8741 )


def glInitTextureEnvDot3EXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.pixel_transform

Overview (from the spec)
	
	This extension provides support for scaling, rotation, translation and
	shearing of two-dimensional pixel rectangles in the pixel rasterizer.
	The transformation is defined via a 4x4 matrix, where only those entries
	which apply as a 2D affine transformation will be accepted and used.
	These matrices can be manipulated using the same functions as the other 
	OpenGL matrix stacks.
	

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/pixel_transform.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_pixel_transform'
GL_PIXEL_TRANSFORM_2D_EXT = constant.Constant( 'GL_PIXEL_TRANSFORM_2D_EXT', 0x8330 )
GL_PIXEL_MAG_FILTER_EXT = constant.Constant( 'GL_PIXEL_MAG_FILTER_EXT', 0x8331 )
GL_PIXEL_MIN_FILTER_EXT = constant.Constant( 'GL_PIXEL_MIN_FILTER_EXT', 0x8332 )
GL_PIXEL_CUBIC_WEIGHT_EXT = constant.Constant( 'GL_PIXEL_CUBIC_WEIGHT_EXT', 0x8333 )
GL_CUBIC_EXT = constant.Constant( 'GL_CUBIC_EXT', 0x8334 )
GL_AVERAGE_EXT = constant.Constant( 'GL_AVERAGE_EXT', 0x8335 )
GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT = constant.Constant( 'GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT', 0x8336 )
GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT = constant.Constant( 'GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT', 0x8337 )
GL_PIXEL_TRANSFORM_2D_MATRIX_EXT = constant.Constant( 'GL_PIXEL_TRANSFORM_2D_MATRIX_EXT', 0x8338 )
glPixelTransformParameteriEXT = platform.createExtensionFunction( 
	'glPixelTransformParameteriEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint,),
	doc = 'glPixelTransformParameteriEXT( GLenum(target), GLenum(pname), GLint(param) ) -> None',
	argNames = ('target', 'pname', 'param',),
)

glPixelTransformParameterfEXT = platform.createExtensionFunction( 
	'glPixelTransformParameterfEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLfloat,),
	doc = 'glPixelTransformParameterfEXT( GLenum(target), GLenum(pname), GLfloat(param) ) -> None',
	argNames = ('target', 'pname', 'param',),
)

glPixelTransformParameterivEXT = platform.createExtensionFunction( 
	'glPixelTransformParameterivEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glPixelTransformParameterivEXT( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glPixelTransformParameterfvEXT = platform.createExtensionFunction( 
	'glPixelTransformParameterfvEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glPixelTransformParameterfvEXT( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)


def glInitPixelTransformEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension HP.image_transform

Overview (from the spec)
	
	This extension provides support for scaling, rotation, and translation
	of two-dimensional pixel rectangles at a fixed location in the pixel
	transfer process.  The 2D image transformation attributes are specified
	as individual values so that that implementations may easily detect
	scaling and rotation values that lend themselves to optimization.  2D
	image transformation occurs immediately after the post-convolution color
	table stage of the pixel pipeline.  This extension also defines a color
	table that is applied immediately after the image transformation operation.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/HP/image_transform.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_HP_image_transform'
GL_IMAGE_SCALE_X_HP = constant.Constant( 'GL_IMAGE_SCALE_X_HP', 0x8155 )
GL_IMAGE_SCALE_Y_HP = constant.Constant( 'GL_IMAGE_SCALE_Y_HP', 0x8156 )
GL_IMAGE_TRANSLATE_X_HP = constant.Constant( 'GL_IMAGE_TRANSLATE_X_HP', 0x8157 )
GL_IMAGE_TRANSLATE_Y_HP = constant.Constant( 'GL_IMAGE_TRANSLATE_Y_HP', 0x8158 )
GL_IMAGE_ROTATE_ANGLE_HP = constant.Constant( 'GL_IMAGE_ROTATE_ANGLE_HP', 0x8159 )
GL_IMAGE_ROTATE_ORIGIN_X_HP = constant.Constant( 'GL_IMAGE_ROTATE_ORIGIN_X_HP', 0x815A )
GL_IMAGE_ROTATE_ORIGIN_Y_HP = constant.Constant( 'GL_IMAGE_ROTATE_ORIGIN_Y_HP', 0x815B )
GL_IMAGE_MAG_FILTER_HP = constant.Constant( 'GL_IMAGE_MAG_FILTER_HP', 0x815C )
GL_IMAGE_MIN_FILTER_HP = constant.Constant( 'GL_IMAGE_MIN_FILTER_HP', 0x815D )
GL_IMAGE_CUBIC_WEIGHT_HP = constant.Constant( 'GL_IMAGE_CUBIC_WEIGHT_HP', 0x815E )
GL_CUBIC_HP = constant.Constant( 'GL_CUBIC_HP', 0x815F )
GL_AVERAGE_HP = constant.Constant( 'GL_AVERAGE_HP', 0x8160 )
GL_IMAGE_TRANSFORM_2D_HP = constant.Constant( 'GL_IMAGE_TRANSFORM_2D_HP', 0x8161 )
GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP = constant.Constant( 'GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP', 0x8162 )
GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP = constant.Constant( 'GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP', 0x8163 )
glImageTransformParameteriHP = platform.createExtensionFunction( 
	'glImageTransformParameteriHP', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint,),
	doc = 'glImageTransformParameteriHP( GLenum(target), GLenum(pname), GLint(param) ) -> None',
	argNames = ('target', 'pname', 'param',),
)

glImageTransformParameterfHP = platform.createExtensionFunction( 
	'glImageTransformParameterfHP', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLfloat,),
	doc = 'glImageTransformParameterfHP( GLenum(target), GLenum(pname), GLfloat(param) ) -> None',
	argNames = ('target', 'pname', 'param',),
)

glImageTransformParameterivHP = platform.createExtensionFunction( 
	'glImageTransformParameterivHP', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glImageTransformParameterivHP( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glImageTransformParameterfvHP = platform.createExtensionFunction( 
	'glImageTransformParameterfvHP', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glImageTransformParameterfvHP( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetImageTransformParameterivHP = platform.createExtensionFunction( 
	'glGetImageTransformParameterivHP', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetImageTransformParameterivHP( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetImageTransformParameterfvHP = platform.createExtensionFunction( 
	'glGetImageTransformParameterfvHP', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetImageTransformParameterfvHP( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)


def glInitImageTransformHP():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



#! /usr/bin/env python
import unittest, pygame, pygame.display, time, traceback
try:
	from numpy import *
except ImportError, err:
	from Numeric import *
pygame.display.init()
from OpenGL.GL import *
from OpenGL import constants, error
from OpenGL.GLU import *
from OpenGL.arrays import arraydatatype
import OpenGL
import ctypes
from OpenGL.GL.EXT.framebuffer_object import *


class Test( unittest.TestCase ):
	evaluator_ctrlpoints = [[[ -1.5, -1.5, 4.0], [-0.5, -1.5, 2.0], [0.5, -1.5,
		-1.0], [1.5, -1.5, 2.0]], [[-1.5, -0.5, 1.0], [-0.5, -0.5, 3.0], [0.5, -0.5,
		0.0], [1.5, -0.5, -1.0]], [[-1.5, 0.5, 4.0], [-0.5, 0.5, 0.0], [0.5, 0.5,
		3.0], [1.5, 0.5, 4.0]], [[-1.5, 1.5, -2.0], [-0.5, 1.5, -2.0], [0.5, 1.5,
		0.0], [1.5, 1.5, -1.0]]]
	width = height = 300
	def setUp( self ):
		"""Set up the operation"""
		
		self.screen = pygame.display.set_mode(
			(self.width,self.height),
			pygame.OPENGL | pygame.DOUBLEBUF,
		)
		
		pygame.display.set_caption('Testing system')
		pygame.key.set_repeat(500,30)
		glMatrixMode (GL_PROJECTION)
		glLoadIdentity()
		gluPerspective(40.0, 300/300, 1.0, 20.0)
		glMatrixMode(GL_MODELVIEW)
		glLoadIdentity()
		gluLookAt(
			-2,0,3, # eyepoint
			0,0,0, # center-of-view
			0,1,0, # up-vector
		)
		glClearColor( 0,0,.25, 0 )
		glClear( GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT )
	def tearDown( self ):
		glFlush()
		pygame.display.flip()
		time.sleep( .25 )
		#raw_input( 'Okay? ' )
	def test_arrayPointer( self ):
		dt = arraydatatype.GLuintArray
		d = dt.zeros( (3,))
		dp = dt.typedPointer( d )
		assert dp[0] == 0 
		assert dp[1] == 0
		assert dp[2] == 0
		dp[1] = 1
		assert dp[1] == 1
		assert d[1] == 1
	def test_evaluator( self ):
		"""Test whether the evaluator functions work"""
		glDisable(GL_CULL_FACE)
		glEnable(GL_MAP2_VERTEX_3)
		glEnable(GL_DEPTH_TEST)
		glEnable(GL_NORMALIZE)
		glMap2f(GL_MAP2_VERTEX_3, 0, 1, 0, 1, self.evaluator_ctrlpoints)
		glMapGrid2f(20, 0.0, 1.0, 20, 0.0, 1.0)
		glShadeModel(GL_FLAT)
		glEvalMesh2(GL_FILL, 0, 20, 0, 20)
		glTranslatef( 0,0.001, 0 )
		glEvalMesh2(GL_POINT, 0, 20, 0, 20)
	def test_nurbs_raw( self ):
		"""Test nurbs rendering using raw API calls"""
		from OpenGL.raw import GLU 
		knots = (constants.GLfloat* 8) ( 0,0,0,0,1,1,1,1 )
		ctlpoints = (constants.GLfloat*(3*4*4))( -3., -3., -3.,
			-3., -1., -3.,
			-3.,  1., -3.,
			-3.,  3., -3.,

		-1., -3., -3.,
			-1., -1.,  3.,
			-1.,  1.,  3.,
			-1.,  3., -3.,

		1., -3., -3.,
			 1., -1.,  3.,
			 1.,  1.,  3.,
			 1.,  3., -3.,

		3., -3., -3.,
			3., -1., -3.,
			 3.,  1., -3.,
			 3.,  3., -3. )
		theNurb = gluNewNurbsRenderer()
		GLU.gluBeginSurface(theNurb)
		GLU.gluNurbsSurface(
			theNurb, 
			8, ctypes.byref(knots), 8, ctypes.byref(knots),
			4 * 3, 3, ctypes.byref( ctlpoints ),
			4, 4, GL_MAP2_VERTEX_3
		)
		GLU.gluEndSurface(theNurb)
	def test_nurbs_raw_arrays( self ):
		"""Test nurbs rendering using raw API calls with arrays"""
		from OpenGL.raw import GLU 
		import numpy
		knots = numpy.array( ( 0,0,0,0,1,1,1,1 ), 'f' )
		ctlpoints = numpy.array( [[[-3., -3., -3.],
			[-3., -1., -3.],
			[-3.,  1., -3.],
			[-3.,  3., -3.]],

		[[-1., -3., -3.],
			[-1., -1.,  3.],
			[-1.,  1.,  3.],
			[-1.,  3., -3.]],

		[[ 1., -3., -3.],
			[ 1., -1.,  3.],
			[ 1.,  1.,  3.],
			[ 1.,  3., -3.]],

		[[ 3., -3., -3.],
			[ 3., -1., -3.],
			[ 3.,  1., -3.],
			[ 3.,  3., -3.]]], 'f' )
		theNurb = GLU.gluNewNurbsRenderer()
		GLU.gluBeginSurface(theNurb)
		GLU.gluNurbsSurface(
			theNurb, 
			8, knots, 8, knots,
			4 * 3, 3, ctlpoints ,
			4, 4, GL_MAP2_VERTEX_3
		)
		GLU.gluEndSurface(theNurb)
	def test_nurbs( self ):
		"""Test nurbs rendering"""
		from OpenGL.raw import GLU 
		def buildControlPoints( ):
			ctlpoints = zeros( (4,4,3), 'd')
			for u in range( 4 ):
				for v in range( 4):
					ctlpoints[u][v][0] = 2.0*(u - 1.5)
					ctlpoints[u][v][1] = 2.0*(v - 1.5);
					if (u == 1 or u ==2) and (v == 1 or v == 2):
						ctlpoints[u][v][2] = 3.0;
					else:
						ctlpoints[u][v][2] = -3.0;
			return ctlpoints
		controlPoints = buildControlPoints()
		theNurb = GLU.gluNewNurbsRenderer()[0]
		#theNurb = gluNewNurbsRenderer();
		gluNurbsProperty(theNurb, GLU_SAMPLING_TOLERANCE, 25.0);
		gluNurbsProperty(theNurb, GLU_DISPLAY_MODE, GLU_FILL);
		knots= array ([0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 1.0], "d")
		glPushMatrix();
		try:
			glRotatef(330.0, 1.,0.,0.);
			glScalef (0.5, 0.5, 0.5);

			gluBeginSurface(theNurb);
			try:
				gluNurbsSurface(
					theNurb,
					knots, knots,
					controlPoints,
					GL_MAP2_VERTEX_3
				);
			finally:
				gluEndSurface(theNurb);
		finally:
			glPopMatrix();
	def test_errors( self ):
		"""Test for error catching/checking"""
		try:
			glClear( GL_INVALID_VALUE )
		except Exception, err:
			assert err.err == 1281, ("""Expected invalid value (1281)""", err.err)
		else:
			raise RuntimeError( """No error on invalid glClear""" )
		try:
			glColorPointer(GL_INVALID_VALUE,GL_BYTE,0,None)
		except Exception, err:
			assert err.err == 1281, ("""Expected invalid value (1281)""", err.err)
			assert err.baseOperation, err.baseOperation
			assert err.pyArgs == [GL_INVALID_VALUE, GL_BYTE, 0, None], err.pyArgs
			assert err.cArgs == [GL_INVALID_VALUE, GL_BYTE, 0, None], err.cArgs
		else:
			raise RuntimeError( """No error on invalid glColorPointer""" )
		try:
			glBitmap(-1,-1,0,0,0,0,"")
		except Exception, err:
			assert err.err == 1281, ("""Expected invalid value (1281)""", err.err)
		else:
			raise RuntimeError( """No error on invalid glBitmap""" )
	def test_quadrics( self ):
		"""Test for rendering quadric objects"""
		quad = gluNewQuadric()
		glColor3f( 1,0, 0 )
		gluSphere( quad, 1.0, 16, 16 )
	def test_simple( self ):
		"""Test for simple vertex-based drawing"""
		glDisable( GL_LIGHTING )
		glBegin( GL_TRIANGLES )
		try:
			try:
				glVertex3f( 0.,1.,0. )
			except Exception, err:
				traceback.print_exc()
			glVertex3fv( [-1,0,0] )
			glVertex3dv( [1,0,0] )
			try:
				glVertex3dv( [1,0] )
			except ValueError, err:
				#Got expected value error (good)
				pass
			else:
				raise RuntimeError(
					"""Should have raised a value error on passing 2-element array to 3-element function!""",
				)
		finally:
			glEnd()
		a = glGenTextures( 1 )
		assert a
		b = glGenTextures( 2 )
		assert len(b) == 2
	def test_arbwindowpos( self ):
		"""Test the ARB window_pos extension will load if available"""
		from OpenGL.GL.ARB.window_pos import glWindowPos2dARB
		if glWindowPos2dARB:
			glWindowPos2dARB( 0.0, 3.0 )
	def test_getstring( self ):
		assert glGetString( GL_EXTENSIONS )
	def test_pointers( self ):
		"""Test that basic pointer functions work"""
		vertex = constants.GLdouble * 3
		vArray =  vertex * 2
		glVertexPointerd( [[2,3,4,5],[2,3,4,5]] )
		glVertexPointeri( ([2,3,4,5],[2,3,4,5]) )
		glVertexPointers( [[2,3,4,5],[2,3,4,5]] )
		glVertexPointerd( vArray( vertex(2,3,4),vertex(2,3,4) ) )
		myVector = vArray( vertex(2,3,4),vertex(2,3,4) )
		glVertexPointer(
			3,
			GL_DOUBLE,
			0,
			ctypes.cast( myVector, ctypes.POINTER(constants.GLdouble)) 
		)
		
		repr(glVertexPointerb( [[2,3],[4,5]] ))
		glVertexPointerf( [[2,3],[4,5]] )
		assert arrays.ArrayDatatype.dataPointer( None ) == None
		glVertexPointerf( None )
		
		glNormalPointerd( [[2,3,4],[2,3,4]] )
		glNormalPointerd( None )
	
		glTexCoordPointerd( [[2,3,4],[2,3,4]] )
		glTexCoordPointerd( None )
	
		glColorPointerd( [[2,3,4],[2,3,4]] )
		glColorPointerd( None )
	
		glEdgeFlagPointerb( [0,1,0,0,1,0] )
		glEdgeFlagPointerb( None )
	
		glIndexPointerd( [0,1,0,0,1,0] )
		glIndexPointerd( None )
		
		glColor4fv( [0,0,0,1] )
		
		# string data-types...
		import struct
		s = struct.pack( '>iiii', 2,3,4,5 ) * 2
		result = glVertexPointer( 4,GL_INT,0,s )
	TESS_TEST_SHAPE = [
			[191,   0],
			[ 191, 1480],
			[ 191, 1480],
			[ 401, 1480],
			[ 401, 1480],
			[401,   856],
			[401,   856],
			[1105,  856],
			[1105,  856],
			[1105, 1480],
			[1105, 1480],
			[1315, 1480],
			[1315, 1480],
			[1315,    0],
			[1315,    0],
			[1105,    0],
			[1105,    0],
			[1105,  699],
			[1105,  699],
			[401,   699],
			[401,   699],
			[401,     0],
			[401,     0],
			[191,     0],
			[191,     0],
			[191,     0],
		]
	def test_tess(self ):
		"""Test that tessellation works"""
		glDisable( GL_LIGHTING )
		glColor3f( 1,1,1 )
		glNormal3f( 0,0,1 )
		def begin( *args ):
			return glBegin( *args )
		def vertex( *args ):
			return glVertex3dv( *args )
		def end( *args ):
			return glEnd( *args )
		def combine( coords, vertex_data, weight):
			return coords
		tobj = gluNewTess()
		gluTessCallback(tobj, GLU_TESS_BEGIN, begin);
		gluTessCallback(tobj, GLU_TESS_VERTEX, vertex); 
		gluTessCallback(tobj, GLU_TESS_END, end); 
		gluTessCallback(tobj, GLU_TESS_COMBINE, combine); 
		gluTessBeginPolygon(tobj, None); 
		gluTessBeginContour(tobj);
		for (x,y) in self.TESS_TEST_SHAPE:
			vert = (x,y,0.0)
			gluTessVertex(tobj, vert, vert);
		gluTessEndContour(tobj); 
		gluTessEndPolygon(tobj);
	def test_texture( self ):
		"""Test texture (requires OpenGLContext and PIL)"""
		try:
			from OpenGLContext import texture
			import Image 
			from OpenGL.GLUT import glutSolidTeapot
		except ImportError, err:
			pass
		else:
			glEnable( GL_TEXTURE_2D )
			ourTexture = texture.Texture(
				Image.open( 'yingyang.png' )
			)
			ourTexture()
			
			glEnable( GL_LIGHTING )
			glEnable( GL_LIGHT0 )
			glBegin( GL_TRIANGLES )
			try:
				try:
					glTexCoord2f( .5, 1 )
					glVertex3f( 0.,1.,0. )
				except Exception, err:
					traceback.print_exc()
				glTexCoord2f( 0, 0 )
				glVertex3fv( [-1,0,0] )
				glTexCoord2f( 1, 0 )
				glVertex3dv( [1,0,0] )
				try:
					glVertex3dv( [1,0] )
				except ValueError, err:
					#Got expected value error (good)
					pass
				else:
					raise RuntimeError(
						"""Should have raised a value error on passing 2-element array to 3-element function!""",
					)
			finally:
				glEnd()
	def test_numpyConversion( self ):
		"""Test that we can run a numpy conversion from double to float for glColorArray"""
		import numpy
		a = numpy.arange( 0,1.2, .1, 'd' ).reshape( (-1,3 ))
		glEnableClientState(GL_VERTEX_ARRAY)
		glColorPointerf( a )
		glColorPointerd( a )
	def test_constantPickle( self ):
		"""Test that our constants can be pickled/unpickled properly"""
		import pickle, cPickle
		for p in pickle,cPickle:
			v = p.loads( p.dumps( GL_VERTEX_ARRAY ))
			assert v == GL_VERTEX_ARRAY, (v,GL_VERTEX_ARRAY)
			assert v.name == GL_VERTEX_ARRAY.name, v.name 
	
	def test_copyNonContiguous( self ):
		"""Test that a non-contiguous (transposed) array gets applied as a copy"""
		glMatrixMode(GL_MODELVIEW)
		glPushMatrix( )
		try:
			import numpy
			transf = numpy.identity(4, dtype=numpy.float32)
			# some arbitrary transformation...
			transf[0,3] = 2.5
			transf[2,3] = -80
			
			# what do we get with the un-transposed version...
			glMatrixMode(GL_MODELVIEW)
			glLoadIdentity()
			glMultMatrixf(transf)
			untransposed = glGetFloatv(GL_MODELVIEW_MATRIX)
			# now transposed...

			# with a copy it works...
			t2 = transf.transpose().copy()
			# This doesn't work:
			glLoadIdentity()
			glMultMatrixf(t2)
			# This does work:
			#glMultMatrixf(transf.transpose().copy())
			transposed = glGetFloatv(GL_MODELVIEW_MATRIX)

			assert not numpy.allclose( transposed, untransposed ), (transposed, untransposed)
			
			t2 = transf.transpose()
			# This doesn't work:
			glLoadIdentity()
			glMultMatrixf(t2)
			# This does work:
			#glMultMatrixf(transf.transpose().copy())
			transposed = glGetFloatv(GL_MODELVIEW_MATRIX)
			
			assert not numpy.allclose( transposed, untransposed ), (transposed, untransposed)
		finally:
			glMatrixMode(GL_MODELVIEW)
			glPopMatrix()
	def test_nullTexture( self ):
		"""Test that we can create null textures"""
		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB8, 512, 512, 0, GL_RGB, GL_INT, None)
	
	def test_nonFloatColor( self ):
		"""Test that we handle non-floating-point colour inputs"""
		for notFloat,shouldWork in ((0,True), (object(),False), (object,False)):
			try:
				glColor4f( 0,1,1,notFloat )
			except Exception, err:
				if shouldWork:
					raise 
			else:
				if not shouldWork:
					raise RuntimeError( """Expected failure for non-float value %s, succeeded"""%( notFloat, ))
	someData = [ (0,255,0)]
	def test_glAreTexturesResident( self ):
		"""Test that PyOpenGL api for glAreTexturesResident is working
		
		Note: not currently working on AMD64 Linux for some reason
		"""
		import numpy
		textures = glGenTextures(2)
		residents = []
		for texture in textures:
			glBindTexture( GL_TEXTURE_2D,int(texture) )
			glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB8, 1, 1, 0, GL_RGB, GL_INT, self.someData)
			residents.append(
				glGetTexParameteriv(GL_TEXTURE_2D, GL_TEXTURE_RESIDENT )
			)
		error.glCheckError(None)
		result = glAreTexturesResident( textures)
		assert len(result) == 2
		for (tex,expected,found) in zip( textures, residents, result ):
			if expected != found:
				print 'Warning: texture %s residence expected %s got %s'%( tex, expected, found )
		
	if OpenGL.ALLOW_NUMPY_SCALARS:
		def test_passBackResults( self ):
			"""Test ALLOW_NUMPY_SCALARS to allow numpy scalars to be passed in"""
			textures = glGenTextures(2)
			glBindTexture( GL_TEXTURE_2D, textures[0] )
	def test_arrayTranspose( self ):
		import numpy
		m = glGetFloatv( GL_MODELVIEW_MATRIX )
		glMatrixMode( GL_MODELVIEW )
		glLoadIdentity()

		t = eye(4)
		t[3,0] = 20.0

		# the following glMultMatrixf call ignored this transpose
		t = t.T

		glMultMatrixf( t )

		m = glGetFloatv( GL_MODELVIEW_MATRIX )
		assert numpy.allclose( m[-1], [0,0,0,1] ), m
	def test_glreadpixelsf( self ):
		"""Issue #1979002 crash due to mis-calculation of resulting array size"""
		width,height = self.width, self.height
		readback_image1 = glReadPixelsub(0,0,width,height,GL_RGB)
		readback_image2 = glReadPixelsf(0,0,width,height,GL_RGB)
	def test_glreadpixels_is_string( self ):
		"""Issue #1959860 incompatable change to returning arrays reversed"""
		width,height = self.width, self.height
		readback_image1 = glReadPixels(0,0,width,height,GL_RGB, GL_UNSIGNED_BYTE)
		assert isinstance( readback_image1, str ), type( readback_image1 )
		readback_image1 = glReadPixels(0,0,width,height,GL_RGB, GL_BYTE)
		assert not isinstance( readback_image1, str ), type(readback_image2)
	
	def test_mmap_data( self ):
		"""Test that we can use mmap data array
		
		If we had a reasonable lib that dumped raw image data to a shared-mem file
		we might be able to use this for movie display :) 
		"""
		fh = open( 'mmap-test-data.dat', 'w+' )
		fh.write( '\000'*(32*32*3+1))
		fh.flush()
		fh.close()
		# using numpy.memmap here...
		data = memmap( 'mmap-test-data.dat' )
		for i in range( 0,255,2 ):
			glDrawPixels( 32,32, GL_RGB, GL_UNSIGNED_BYTE, data, )
			glFlush()
			pygame.display.flip()
			data[::2] = i
			time.sleep( 0.001 )
	
	def test_vbo( self ):
		"""Test utility vbo wrapper"""
		import numpy
		from OpenGL.arrays import vbo
		assert vbo.get_implementation()
		dt = arraydatatype.GLdoubleArray
		array = numpy.array( [
			[0,0,0],
			[0,1,0],
			[1,.5,0],
			[1,0,0],
			[1.5,.5,0],
			[1.5,0,0],
		], dtype='d')
		indices = numpy.array(
			range(len(array)),
			'i',
		)
		d = vbo.VBO(array)
		glDisable( GL_CULL_FACE )
		glNormal3f( 0,0,1 )
		glColor3f( 1,1,1 )
		glEnableClientState(GL_VERTEX_ARRAY)
		for x in range( 1, 255, 10 ):
			d.bind()
			try:
				glVertexPointerd( d )
				glDrawElements( GL_LINE_LOOP, len(indices), GL_UNSIGNED_INT, indices )
			finally:
				d.unbind()
			lastPoint = [[1.5,(1/255.) * float(x),0]]
			d[-2:-1] = lastPoint
			glFlush()
			pygame.display.flip()
			glClear( GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT )
			time.sleep( 0.001 )
	def test_fbo( self ):
		"""Test that we support framebuffer objects
		
		http://www.gamedev.net/reference/articles/article2331.asp
		"""
		if not glGenFramebuffersEXT:
			return False
		width = height = 128
		fbo = glGenFramebuffersEXT(1)
		glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, fbo)
		depthbuffer = glGenRenderbuffersEXT(1 )
		glBindRenderbufferEXT(GL_RENDERBUFFER_EXT, depthbuffer)
		glRenderbufferStorageEXT(GL_RENDERBUFFER_EXT, GL_DEPTH_COMPONENT24, width, height)
		glFramebufferRenderbufferEXT(
			GL_FRAMEBUFFER_EXT, GL_DEPTH_ATTACHMENT_EXT, GL_RENDERBUFFER_EXT, 
			depthbuffer
		)
		img = glGenTextures(1)
		glBindTexture(GL_TEXTURE_2D, img)
		# NOTE: these lines are *key*, without them you'll likely get an unsupported format error,
		# ie. GL_FRAMEBUFFER_UNSUPPORTED_EXT
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST);
		glTexImage2D(
			GL_TEXTURE_2D, 0, GL_RGB8,  
			width, height, 0, GL_RGB, 
			GL_INT, 
			None # no data transferred
		) 
		glFramebufferTexture2DEXT(
			GL_FRAMEBUFFER_EXT, GL_COLOR_ATTACHMENT0_EXT, GL_TEXTURE_2D, 
			img, 
			0 # mipmap level, normally 0
		)
		status = glCheckFramebufferStatusEXT(GL_FRAMEBUFFER_EXT)
		assert status == GL_FRAMEBUFFER_COMPLETE_EXT, status
		glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, fbo)
		glPushAttrib(GL_VIEWPORT_BIT) # viewport is shared with the main context
		try:
			glViewport(0,0,width, height)
			
			# rendering to the texture here...
			glColor3f( 1,0,0 )
			glNormal3f( 0,0,1 )
			glBegin( GL_QUADS )
			for v in [[0,0,0],[0,1,0],[1,1,0],[1,0,0]]:
				glColor3fv( v )
				glVertex3dv( v )
			glEnd()
		finally:
			glPopAttrib(); # restore viewport
		glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0) # unbind
		
		glBindTexture(GL_TEXTURE_2D, img)
		
		glEnable( GL_TEXTURE_2D )
		
		# rendering with the texture here...
		glColor3f( 1,1,1 )
		glNormal3f( 0,0,1 )
		glDisable( GL_LIGHTING )
		glBegin( GL_QUADS )
		try:
			for v in [[0,0,0],[0,1,0],[1,1,0],[1,0,0]]:
				glTexCoord2fv( v[:2] )
				glVertex3dv( v )
		finally:
			glEnd()
	def test_gl_1_2_support( self ):
		if glBlendColor:
			glBlendColor( .3, .4, 1.0, .3 )
			print 'OpenGL 1.2 support'
		
if __name__ == "__main__":
	import logging 
	logging.basicConfig()
	unittest.main()
	pygame.display.quit()
	pygame.quit()




import pygame
from pygame.locals import *
import pygame.key
import pygame.display
from OpenGL.GLUT import *


def createPyGameContext():
	"""Setup a minimal PyGame context for testing"""
	pygame.display.init()
	screen = pygame.display.set_mode(
		(300,300),
		OPENGL | DOUBLEBUF,
	)
	pygame.display.set_caption("testing")
	pygame.key.set_repeat(500,30)
	return pygame.display

def createGLUTContext():
	"""Setup a minimal GLUT context for testing"""
	glutInit( [] )
	glutInitDisplayMode( GLUT_DOUBLE | GLUT_RGB )
	glutInitWindowSize(250, 250)
	glutInitWindowPosition(100, 100)
	window = glutCreateWindow("hello")
	return window



'''OpenGL extension ARB.vertex_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.vertex_buffer_object to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.vertex_buffer_object import *
### END AUTOGENERATED SECTION

glDeleteBuffersARB = arrays.setInputArraySizeType(
	glDeleteBuffersARB,
	None,
	arrays.GLuintArray,
	'buffers',
)

glGenBuffersARB = wrapper.wrapper( glGenBuffersARB ).setOutput(
	'buffers', lambda n: (n,), 'n',
)

def _sizeOfArrayInput( pyArgs, index, wrapper ):
	return (
		arrays.ArrayDatatype.arrayByteCount( pyArgs[index] )
	)

glBufferDataARB = wrapper.wrapper( glBufferDataARB ).setPyConverter(
	'data', arrays.asVoidArray(),
).setPyConverter( 'size' ).setCResolver( 
	'data', arrays.ArrayDatatype.voidDataPointer ,
).setCConverter(
	'size', _sizeOfArrayInput,
).setReturnValues( 
	wrapper.returnPyArgument( 'data' ) 
)

glBufferSubDataARB = wrapper.wrapper( glBufferSubDataARB ).setPyConverter(
	'data', arrays.asVoidArray(),
).setPyConverter( 'size' ).setCResolver( 
	'data', arrays.ArrayDatatype.voidDataPointer ,
).setCConverter(
	'size', _sizeOfArrayInput,
).setReturnValues( 
	wrapper.returnPyArgument( 'data' ) 
)



# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by gengl.py.
# Wrapper for /usr/include/GL/freeglut_ext.h
from OpenGL import platform
from OpenGL.constants import *
from OpenGL.constant import Constant
from OpenGL.arrays.arraydatatype import *
from ctypes import *
c_void = None


GLUT_ACTION_EXIT=Constant( 'GLUT_ACTION_EXIT', 0 )
GLUT_ACTION_GLUTMAINLOOP_RETURNS=Constant( 'GLUT_ACTION_GLUTMAINLOOP_RETURNS', 1 )
GLUT_ACTION_CONTINUE_EXECUTION=Constant( 'GLUT_ACTION_CONTINUE_EXECUTION', 2 )
GLUT_CREATE_NEW_CONTEXT=Constant( 'GLUT_CREATE_NEW_CONTEXT', 0 )
GLUT_USE_CURRENT_CONTEXT=Constant( 'GLUT_USE_CURRENT_CONTEXT', 1 )
GLUT_FORCE_INDIRECT_CONTEXT=Constant( 'GLUT_FORCE_INDIRECT_CONTEXT', 0 )
GLUT_ALLOW_DIRECT_CONTEXT=Constant( 'GLUT_ALLOW_DIRECT_CONTEXT', 1 )
GLUT_TRY_DIRECT_CONTEXT=Constant( 'GLUT_TRY_DIRECT_CONTEXT', 2 )
GLUT_FORCE_DIRECT_CONTEXT=Constant( 'GLUT_FORCE_DIRECT_CONTEXT', 3 )
GLUT_ACTION_ON_WINDOW_CLOSE=Constant( 'GLUT_ACTION_ON_WINDOW_CLOSE', 505 )
GLUT_WINDOW_BORDER_WIDTH=Constant( 'GLUT_WINDOW_BORDER_WIDTH', 506 )
GLUT_WINDOW_HEADER_HEIGHT=Constant( 'GLUT_WINDOW_HEADER_HEIGHT', 507 )
GLUT_VERSION=Constant( 'GLUT_VERSION', 508 )
GLUT_RENDERING_CONTEXT=Constant( 'GLUT_RENDERING_CONTEXT', 509 )
GLUT_DIRECT_RENDERING=Constant( 'GLUT_DIRECT_RENDERING', 510 )
GLUT_AUX1=Constant( 'GLUT_AUX1', 4096 )
GLUT_AUX2=Constant( 'GLUT_AUX2', 8192 )
GLUT_AUX3=Constant( 'GLUT_AUX3', 16384 )
GLUT_AUX4=Constant( 'GLUT_AUX4', 32768 )
glutMainLoopEvent=platform.createBaseFunction(
	'glutMainLoopEvent',platform.GLUT,None,
	[],
	[],
)
glutLeaveMainLoop=platform.createBaseFunction(
	'glutLeaveMainLoop',platform.GLUT,None,
	[],
	[],
)
glutMouseWheelFunc=platform.createBaseFunction(
	'glutMouseWheelFunc',platform.GLUT,None,
	[CFUNCTYPE(None, c_int, c_int, c_int, c_int)],
	['callback'],
)
glutCloseFunc=platform.createBaseFunction(
	'glutCloseFunc',platform.GLUT,None,
	[CFUNCTYPE(None)],
	['callback'],
)
glutWMCloseFunc=platform.createBaseFunction(
	'glutWMCloseFunc',platform.GLUT,None,
	[CFUNCTYPE(None)],
	['callback'],
)
glutMenuDestroyFunc=platform.createBaseFunction(
	'glutMenuDestroyFunc',platform.GLUT,None,
	[CFUNCTYPE(None)],
	['callback'],
)
glutGetWindowData=platform.createBaseFunction(
	'glutGetWindowData',platform.GLUT,POINTER(c_void),
	[],
	[],
)
glutSetWindowData=platform.createBaseFunction(
	'glutSetWindowData',platform.GLUT,None,
	[POINTER(None)],
	['data'],
)
glutGetMenuData=platform.createBaseFunction(
	'glutGetMenuData',platform.GLUT,POINTER(c_void),
	[],
	[],
)
glutSetMenuData=platform.createBaseFunction(
	'glutSetMenuData',platform.GLUT,None,
	[POINTER(None)],
	['data'],
)
glutBitmapHeight=platform.createBaseFunction(
	'glutBitmapHeight',platform.GLUT,c_int,
	[POINTER(None)],
	['font'],
)
glutBitmapString=platform.createBaseFunction(
	'glutBitmapString',platform.GLUT,None,
	[POINTER(None),POINTER(c_ubyte)],
	['font', 'string'],
)
glutStrokeString=platform.createBaseFunction(
	'glutStrokeString',platform.GLUT,None,
	[POINTER(None),POINTER(c_ubyte)],
	['font', 'string'],
)
glutWireRhombicDodecahedron=platform.createBaseFunction(
	'glutWireRhombicDodecahedron',platform.GLUT,None,
	[],
	[],
)
glutSolidRhombicDodecahedron=platform.createBaseFunction(
	'glutSolidRhombicDodecahedron',platform.GLUT,None,
	[],
	[],
)
GLUTproc = CFUNCTYPE(None) 	# /usr/include/GL/freeglut_ext.h:127
glutGetProcAddress=platform.createBaseFunction(
	'glutGetProcAddress',platform.GLUT,GLUTproc,
	[c_char_p],
	['procName'],
)

__all__ = ['GLUT_ACTION_EXIT', 'GLUT_ACTION_GLUTMAINLOOP_RETURNS',
'GLUT_ACTION_CONTINUE_EXECUTION', 'GLUT_CREATE_NEW_CONTEXT',
'GLUT_USE_CURRENT_CONTEXT', 'GLUT_FORCE_INDIRECT_CONTEXT',
'GLUT_ALLOW_DIRECT_CONTEXT', 'GLUT_TRY_DIRECT_CONTEXT',
'GLUT_FORCE_DIRECT_CONTEXT', 'GLUT_ACTION_ON_WINDOW_CLOSE',
'GLUT_WINDOW_BORDER_WIDTH', 'GLUT_WINDOW_HEADER_HEIGHT', 'GLUT_VERSION',
'GLUT_RENDERING_CONTEXT', 'GLUT_DIRECT_RENDERING', 'GLUT_AUX1', 'GLUT_AUX2',
'GLUT_AUX3', 'GLUT_AUX4', 'glutMainLoopEvent', 'glutLeaveMainLoop',
'glutMouseWheelFunc', 'glutCloseFunc', 'glutWMCloseFunc',
'glutMenuDestroyFunc', 'glutGetWindowData', 'glutSetWindowData',
'glutGetMenuData', 'glutSetMenuData', 'glutBitmapHeight', 'glutBitmapString',
'glutStrokeString', 'glutWireRhombicDodecahedron',
'glutSolidRhombicDodecahedron', 'GLUTproc', 'glutGetProcAddress']
# END GENERATED CONTENT (do not edit above this line)





#! /usr/bin/env python
"""Test that GLUT.glutInit accepts 0 arguments"""
from OpenGL import GLUT

if __name__ == "__main__":
	try:
		GLUT.glutInit()
	except Exception, err:
		raise
	else:
		print 'accepted 0 arguments, as desired'
	


'''OpenGL extension ARB.shadow

Overview (from the spec)
	
	This extension clarifies the GL_SGIX_shadow extension.
	
	This extension supports comparing the texture R coordinate to a depth
	texture value in order to produce a boolean texture value.	This can
	be used to implement shadow maps.
	
	The extension is written in generic terms such that other texture
	comparison modes can be accomodated in the future.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/shadow.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_shadow'
GL_TEXTURE_COMPARE_MODE_ARB = constant.Constant( 'GL_TEXTURE_COMPARE_MODE_ARB', 0x884C )
GL_TEXTURE_COMPARE_FUNC_ARB = constant.Constant( 'GL_TEXTURE_COMPARE_FUNC_ARB', 0x884D )
GL_COMPARE_R_TO_TEXTURE_ARB = constant.Constant( 'GL_COMPARE_R_TO_TEXTURE_ARB', 0x884E )


def glInitShadowARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture3D

Overview (from the spec)
	
	This extension defines 3-dimensional texture mapping.  In order to
	define a 3D texture image conveniently, this extension also defines the
	in-memory formats for 3D images, and adds pixel storage modes to support
	them.
	
	One important application of 3D textures is rendering volumes of image
	data.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/texture3D.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture3D'
GL_PACK_SKIP_IMAGES_EXT = constant.Constant( 'GL_PACK_SKIP_IMAGES_EXT', 0x806B )
glget.addGLGetConstant( GL_PACK_SKIP_IMAGES_EXT, (1,) )
GL_PACK_IMAGE_HEIGHT_EXT = constant.Constant( 'GL_PACK_IMAGE_HEIGHT_EXT', 0x806C )
glget.addGLGetConstant( GL_PACK_IMAGE_HEIGHT_EXT, (1,) )
GL_UNPACK_SKIP_IMAGES_EXT = constant.Constant( 'GL_UNPACK_SKIP_IMAGES_EXT', 0x806D )
glget.addGLGetConstant( GL_UNPACK_SKIP_IMAGES_EXT, (1,) )
GL_UNPACK_IMAGE_HEIGHT_EXT = constant.Constant( 'GL_UNPACK_IMAGE_HEIGHT_EXT', 0x806E )
glget.addGLGetConstant( GL_UNPACK_IMAGE_HEIGHT_EXT, (1,) )
GL_TEXTURE_3D_EXT = constant.Constant( 'GL_TEXTURE_3D_EXT', 0x806F )
glget.addGLGetConstant( GL_TEXTURE_3D_EXT, (1,) )
GL_PROXY_TEXTURE_3D_EXT = constant.Constant( 'GL_PROXY_TEXTURE_3D_EXT', 0x8070 )
GL_TEXTURE_DEPTH_EXT = constant.Constant( 'GL_TEXTURE_DEPTH_EXT', 0x8071 )
GL_TEXTURE_WRAP_R_EXT = constant.Constant( 'GL_TEXTURE_WRAP_R_EXT', 0x8072 )
GL_MAX_3D_TEXTURE_SIZE_EXT = constant.Constant( 'GL_MAX_3D_TEXTURE_SIZE_EXT', 0x8073 )
glget.addGLGetConstant( GL_MAX_3D_TEXTURE_SIZE_EXT, (1,) )
glTexImage3DEXT = platform.createExtensionFunction( 
	'glTexImage3DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glTexImage3DEXT( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'depth', 'border', 'format', 'type', 'pixels',),
)

glTexSubImage3DEXT = platform.createExtensionFunction( 
	'glTexSubImage3DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glTexSubImage3DEXT( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'zoffset', 'width', 'height', 'depth', 'format', 'type', 'pixels',),
)


def glInitTexture3DEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_env_combine

Overview (from the spec)
	
	    New texture environment function COMBINE_EXT allows programmable
	    texture combiner operations, including:
	
	        REPLACE                 Arg0
	        MODULATE                Arg0 * Arg1
	        ADD                     Arg0 + Arg1
		ADD_SIGNED_EXT          Arg0 + Arg1 - 0.5
	        INTERPOLATE_EXT         Arg0 * (Arg2) + Arg1 * (1-Arg2)
	
	    where Arg0, Arg1 and Arg2 are derived from
	
		PRIMARY_COLOR_EXT       primary color of incoming fragment
	        TEXTURE                 texture color of corresponding texture unit
	        CONSTANT_EXT            texture environment constant color
	        PREVIOUS_EXT            result of previous texture environment; on
					texture unit 0, this maps to PRIMARY_COLOR_EXT
	
	    and Arg2 is restricted to the alpha component of the corresponding source.
	
	    In addition, the result may be scaled by 1.0, 2.0 or 4.0.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/texture_env_combine.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_env_combine'
GL_COMBINE_EXT = constant.Constant( 'GL_COMBINE_EXT', 0x8570 )
GL_COMBINE_RGB_EXT = constant.Constant( 'GL_COMBINE_RGB_EXT', 0x8571 )
GL_COMBINE_ALPHA_EXT = constant.Constant( 'GL_COMBINE_ALPHA_EXT', 0x8572 )
GL_RGB_SCALE_EXT = constant.Constant( 'GL_RGB_SCALE_EXT', 0x8573 )
GL_ADD_SIGNED_EXT = constant.Constant( 'GL_ADD_SIGNED_EXT', 0x8574 )
GL_INTERPOLATE_EXT = constant.Constant( 'GL_INTERPOLATE_EXT', 0x8575 )
GL_CONSTANT_EXT = constant.Constant( 'GL_CONSTANT_EXT', 0x8576 )
GL_PRIMARY_COLOR_EXT = constant.Constant( 'GL_PRIMARY_COLOR_EXT', 0x8577 )
GL_PREVIOUS_EXT = constant.Constant( 'GL_PREVIOUS_EXT', 0x8578 )
GL_SOURCE0_RGB_EXT = constant.Constant( 'GL_SOURCE0_RGB_EXT', 0x8580 )
GL_SOURCE1_RGB_EXT = constant.Constant( 'GL_SOURCE1_RGB_EXT', 0x8581 )
GL_SOURCE2_RGB_EXT = constant.Constant( 'GL_SOURCE2_RGB_EXT', 0x8582 )
GL_SOURCE0_ALPHA_EXT = constant.Constant( 'GL_SOURCE0_ALPHA_EXT', 0x8588 )
GL_SOURCE1_ALPHA_EXT = constant.Constant( 'GL_SOURCE1_ALPHA_EXT', 0x8589 )
GL_SOURCE2_ALPHA_EXT = constant.Constant( 'GL_SOURCE2_ALPHA_EXT', 0x858A )
GL_OPERAND0_RGB_EXT = constant.Constant( 'GL_OPERAND0_RGB_EXT', 0x8590 )
GL_OPERAND1_RGB_EXT = constant.Constant( 'GL_OPERAND1_RGB_EXT', 0x8591 )
GL_OPERAND2_RGB_EXT = constant.Constant( 'GL_OPERAND2_RGB_EXT', 0x8592 )
GL_OPERAND0_ALPHA_EXT = constant.Constant( 'GL_OPERAND0_ALPHA_EXT', 0x8598 )
GL_OPERAND1_ALPHA_EXT = constant.Constant( 'GL_OPERAND1_ALPHA_EXT', 0x8599 )
GL_OPERAND2_ALPHA_EXT = constant.Constant( 'GL_OPERAND2_ALPHA_EXT', 0x859A )


def glInitTextureEnvCombineEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_2

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/VERSION/GL_1_2.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_2'
GL_UNSIGNED_BYTE_3_3_2 = constant.Constant( 'GL_UNSIGNED_BYTE_3_3_2', 0x8032 )
GL_UNSIGNED_SHORT_4_4_4_4 = constant.Constant( 'GL_UNSIGNED_SHORT_4_4_4_4', 0x8033 )
GL_UNSIGNED_SHORT_5_5_5_1 = constant.Constant( 'GL_UNSIGNED_SHORT_5_5_5_1', 0x8034 )
GL_UNSIGNED_INT_8_8_8_8 = constant.Constant( 'GL_UNSIGNED_INT_8_8_8_8', 0x8035 )
GL_UNSIGNED_INT_10_10_10_2 = constant.Constant( 'GL_UNSIGNED_INT_10_10_10_2', 0x8036 )
GL_RESCALE_NORMAL = constant.Constant( 'GL_RESCALE_NORMAL', 0x803A )
GL_TEXTURE_BINDING_3D = constant.Constant( 'GL_TEXTURE_BINDING_3D', 0x806A )
GL_PACK_SKIP_IMAGES = constant.Constant( 'GL_PACK_SKIP_IMAGES', 0x806B )
GL_PACK_IMAGE_HEIGHT = constant.Constant( 'GL_PACK_IMAGE_HEIGHT', 0x806C )
GL_UNPACK_SKIP_IMAGES = constant.Constant( 'GL_UNPACK_SKIP_IMAGES', 0x806D )
GL_UNPACK_IMAGE_HEIGHT = constant.Constant( 'GL_UNPACK_IMAGE_HEIGHT', 0x806E )
GL_TEXTURE_3D = constant.Constant( 'GL_TEXTURE_3D', 0x806F )
GL_PROXY_TEXTURE_3D = constant.Constant( 'GL_PROXY_TEXTURE_3D', 0x8070 )
GL_TEXTURE_DEPTH = constant.Constant( 'GL_TEXTURE_DEPTH', 0x8071 )
GL_TEXTURE_WRAP_R = constant.Constant( 'GL_TEXTURE_WRAP_R', 0x8072 )
GL_MAX_3D_TEXTURE_SIZE = constant.Constant( 'GL_MAX_3D_TEXTURE_SIZE', 0x8073 )
GL_UNSIGNED_BYTE_2_3_3_REV = constant.Constant( 'GL_UNSIGNED_BYTE_2_3_3_REV', 0x8362 )
GL_UNSIGNED_SHORT_5_6_5 = constant.Constant( 'GL_UNSIGNED_SHORT_5_6_5', 0x8363 )
GL_UNSIGNED_SHORT_5_6_5_REV = constant.Constant( 'GL_UNSIGNED_SHORT_5_6_5_REV', 0x8364 )
GL_UNSIGNED_SHORT_4_4_4_4_REV = constant.Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_REV', 0x8365 )
GL_UNSIGNED_SHORT_1_5_5_5_REV = constant.Constant( 'GL_UNSIGNED_SHORT_1_5_5_5_REV', 0x8366 )
GL_UNSIGNED_INT_8_8_8_8_REV = constant.Constant( 'GL_UNSIGNED_INT_8_8_8_8_REV', 0x8367 )
GL_UNSIGNED_INT_2_10_10_10_REV = constant.Constant( 'GL_UNSIGNED_INT_2_10_10_10_REV', 0x8368 )
GL_BGR = constant.Constant( 'GL_BGR', 0x80E0 )
GL_BGRA = constant.Constant( 'GL_BGRA', 0x80E1 )
GL_MAX_ELEMENTS_VERTICES = constant.Constant( 'GL_MAX_ELEMENTS_VERTICES', 0x80E8 )
GL_MAX_ELEMENTS_INDICES = constant.Constant( 'GL_MAX_ELEMENTS_INDICES', 0x80E9 )
GL_CLAMP_TO_EDGE = constant.Constant( 'GL_CLAMP_TO_EDGE', 0x812F )
GL_TEXTURE_MIN_LOD = constant.Constant( 'GL_TEXTURE_MIN_LOD', 0x813A )
GL_TEXTURE_MAX_LOD = constant.Constant( 'GL_TEXTURE_MAX_LOD', 0x813B )
GL_TEXTURE_BASE_LEVEL = constant.Constant( 'GL_TEXTURE_BASE_LEVEL', 0x813C )
GL_TEXTURE_MAX_LEVEL = constant.Constant( 'GL_TEXTURE_MAX_LEVEL', 0x813D )
GL_LIGHT_MODEL_COLOR_CONTROL = constant.Constant( 'GL_LIGHT_MODEL_COLOR_CONTROL', 0x81F8 )
GL_SINGLE_COLOR = constant.Constant( 'GL_SINGLE_COLOR', 0x81F9 )
GL_SEPARATE_SPECULAR_COLOR = constant.Constant( 'GL_SEPARATE_SPECULAR_COLOR', 0x81FA )
GL_SMOOTH_POINT_SIZE_RANGE = constant.Constant( 'GL_SMOOTH_POINT_SIZE_RANGE', 0xB12 )
GL_SMOOTH_POINT_SIZE_GRANULARITY = constant.Constant( 'GL_SMOOTH_POINT_SIZE_GRANULARITY', 0xB13 )
GL_SMOOTH_LINE_WIDTH_RANGE = constant.Constant( 'GL_SMOOTH_LINE_WIDTH_RANGE', 0xB22 )
GL_SMOOTH_LINE_WIDTH_GRANULARITY = constant.Constant( 'GL_SMOOTH_LINE_WIDTH_GRANULARITY', 0xB23 )
GL_ALIASED_POINT_SIZE_RANGE = constant.Constant( 'GL_ALIASED_POINT_SIZE_RANGE', 0x846D )
GL_ALIASED_LINE_WIDTH_RANGE = constant.Constant( 'GL_ALIASED_LINE_WIDTH_RANGE', 0x846E )
glBlendColor = platform.createExtensionFunction( 
	'glBlendColor', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLclampf, constants.GLclampf, constants.GLclampf, constants.GLclampf,),
	doc = 'glBlendColor( GLclampf(red), GLclampf(green), GLclampf(blue), GLclampf(alpha) ) -> None',
	argNames = ('red', 'green', 'blue', 'alpha',),
)

glBlendEquation = platform.createExtensionFunction( 
	'glBlendEquation', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glBlendEquation( GLenum(mode) ) -> None',
	argNames = ('mode',),
)

glDrawRangeElements = platform.createExtensionFunction( 
	'glDrawRangeElements', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLuint, constants.GLsizei, constants.GLenum, ctypes.c_void_p,),
	doc = 'glDrawRangeElements( GLenum(mode), GLuint(start), GLuint(end), GLsizei(count), GLenum(type), c_void_p(indices) ) -> None',
	argNames = ('mode', 'start', 'end', 'count', 'type', 'indices',),
)

glColorTable = platform.createExtensionFunction( 
	'glColorTable', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glColorTable( GLenum(target), GLenum(internalformat), GLsizei(width), GLenum(format), GLenum(type), c_void_p(table) ) -> None',
	argNames = ('target', 'internalformat', 'width', 'format', 'type', 'table',),
)

glColorTableParameterfv = platform.createExtensionFunction( 
	'glColorTableParameterfv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glColorTableParameterfv( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glColorTableParameteriv = platform.createExtensionFunction( 
	'glColorTableParameteriv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glColorTableParameteriv( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glCopyColorTable = platform.createExtensionFunction( 
	'glCopyColorTable', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei,),
	doc = 'glCopyColorTable( GLenum(target), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width) ) -> None',
	argNames = ('target', 'internalformat', 'x', 'y', 'width',),
)

glGetColorTable = platform.createExtensionFunction( 
	'glGetColorTable', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glGetColorTable( GLenum(target), GLenum(format), GLenum(type), c_void_p(table) ) -> None',
	argNames = ('target', 'format', 'type', 'table',),
)

glGetColorTableParameterfv = platform.createExtensionFunction( 
	'glGetColorTableParameterfv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetColorTableParameterfv( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetColorTableParameteriv = platform.createExtensionFunction( 
	'glGetColorTableParameteriv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetColorTableParameteriv( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glColorSubTable = platform.createExtensionFunction( 
	'glColorSubTable', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glColorSubTable( GLenum(target), GLsizei(start), GLsizei(count), GLenum(format), GLenum(type), c_void_p(data) ) -> None',
	argNames = ('target', 'start', 'count', 'format', 'type', 'data',),
)

glCopyColorSubTable = platform.createExtensionFunction( 
	'glCopyColorSubTable', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLsizei, constants.GLint, constants.GLint, constants.GLsizei,),
	doc = 'glCopyColorSubTable( GLenum(target), GLsizei(start), GLint(x), GLint(y), GLsizei(width) ) -> None',
	argNames = ('target', 'start', 'x', 'y', 'width',),
)

glConvolutionFilter1D = platform.createExtensionFunction( 
	'glConvolutionFilter1D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glConvolutionFilter1D( GLenum(target), GLenum(internalformat), GLsizei(width), GLenum(format), GLenum(type), c_void_p(image) ) -> None',
	argNames = ('target', 'internalformat', 'width', 'format', 'type', 'image',),
)

glConvolutionFilter2D = platform.createExtensionFunction( 
	'glConvolutionFilter2D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glConvolutionFilter2D( GLenum(target), GLenum(internalformat), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(image) ) -> None',
	argNames = ('target', 'internalformat', 'width', 'height', 'format', 'type', 'image',),
)

glConvolutionParameterf = platform.createExtensionFunction( 
	'glConvolutionParameterf', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLfloat,),
	doc = 'glConvolutionParameterf( GLenum(target), GLenum(pname), GLfloat(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glConvolutionParameterfv = platform.createExtensionFunction( 
	'glConvolutionParameterfv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glConvolutionParameterfv( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glConvolutionParameteri = platform.createExtensionFunction( 
	'glConvolutionParameteri', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint,),
	doc = 'glConvolutionParameteri( GLenum(target), GLenum(pname), GLint(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glConvolutionParameteriv = platform.createExtensionFunction( 
	'glConvolutionParameteriv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glConvolutionParameteriv( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glCopyConvolutionFilter1D = platform.createExtensionFunction( 
	'glCopyConvolutionFilter1D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei,),
	doc = 'glCopyConvolutionFilter1D( GLenum(target), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width) ) -> None',
	argNames = ('target', 'internalformat', 'x', 'y', 'width',),
)

glCopyConvolutionFilter2D = platform.createExtensionFunction( 
	'glCopyConvolutionFilter2D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei,),
	doc = 'glCopyConvolutionFilter2D( GLenum(target), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height) ) -> None',
	argNames = ('target', 'internalformat', 'x', 'y', 'width', 'height',),
)

glGetConvolutionFilter = platform.createExtensionFunction( 
	'glGetConvolutionFilter', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glGetConvolutionFilter( GLenum(target), GLenum(format), GLenum(type), c_void_p(image) ) -> None',
	argNames = ('target', 'format', 'type', 'image',),
)

glGetConvolutionParameterfv = platform.createExtensionFunction( 
	'glGetConvolutionParameterfv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetConvolutionParameterfv( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetConvolutionParameteriv = platform.createExtensionFunction( 
	'glGetConvolutionParameteriv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetConvolutionParameteriv( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetSeparableFilter = platform.createExtensionFunction( 
	'glGetSeparableFilter', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLenum, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p,),
	doc = 'glGetSeparableFilter( GLenum(target), GLenum(format), GLenum(type), c_void_p(row), c_void_p(column), c_void_p(span) ) -> None',
	argNames = ('target', 'format', 'type', 'row', 'column', 'span',),
)

glSeparableFilter2D = platform.createExtensionFunction( 
	'glSeparableFilter2D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p, ctypes.c_void_p,),
	doc = 'glSeparableFilter2D( GLenum(target), GLenum(internalformat), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(row), c_void_p(column) ) -> None',
	argNames = ('target', 'internalformat', 'width', 'height', 'format', 'type', 'row', 'column',),
)

glGetHistogram = platform.createExtensionFunction( 
	'glGetHistogram', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLboolean, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glGetHistogram( GLenum(target), GLboolean(reset), GLenum(format), GLenum(type), c_void_p(values) ) -> None',
	argNames = ('target', 'reset', 'format', 'type', 'values',),
)

glGetHistogramParameterfv = platform.createExtensionFunction( 
	'glGetHistogramParameterfv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetHistogramParameterfv( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetHistogramParameteriv = platform.createExtensionFunction( 
	'glGetHistogramParameteriv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetHistogramParameteriv( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetMinmax = platform.createExtensionFunction( 
	'glGetMinmax', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLboolean, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glGetMinmax( GLenum(target), GLboolean(reset), GLenum(format), GLenum(type), c_void_p(values) ) -> None',
	argNames = ('target', 'reset', 'format', 'type', 'values',),
)

glGetMinmaxParameterfv = platform.createExtensionFunction( 
	'glGetMinmaxParameterfv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetMinmaxParameterfv( GLenum(target), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetMinmaxParameteriv = platform.createExtensionFunction( 
	'glGetMinmaxParameteriv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetMinmaxParameteriv( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glHistogram = platform.createExtensionFunction( 
	'glHistogram', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLsizei, constants.GLenum, constants.GLboolean,),
	doc = 'glHistogram( GLenum(target), GLsizei(width), GLenum(internalformat), GLboolean(sink) ) -> None',
	argNames = ('target', 'width', 'internalformat', 'sink',),
)

glMinmax = platform.createExtensionFunction( 
	'glMinmax', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLboolean,),
	doc = 'glMinmax( GLenum(target), GLenum(internalformat), GLboolean(sink) ) -> None',
	argNames = ('target', 'internalformat', 'sink',),
)

glResetHistogram = platform.createExtensionFunction( 
	'glResetHistogram', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glResetHistogram( GLenum(target) ) -> None',
	argNames = ('target',),
)

glResetMinmax = platform.createExtensionFunction( 
	'glResetMinmax', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glResetMinmax( GLenum(target) ) -> None',
	argNames = ('target',),
)

glTexImage3D = platform.createExtensionFunction( 
	'glTexImage3D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glTexImage3D( GLenum(target), GLint(level), GLint(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'depth', 'border', 'format', 'type', 'pixels',),
)

glTexSubImage3D = platform.createExtensionFunction( 
	'glTexSubImage3D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glTexSubImage3D( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'zoffset', 'width', 'height', 'depth', 'format', 'type', 'pixels',),
)

glCopyTexSubImage3D = platform.createExtensionFunction( 
	'glCopyTexSubImage3D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei,),
	doc = 'glCopyTexSubImage3D( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'zoffset', 'x', 'y', 'width', 'height',),
)




'''OpenGL extension NV.texture_env_combine4

Overview (from the spec)
	
	New texture environment function COMBINE4_NV allows programmable
	texture combiner operations, including
	
	    ADD                     Arg0 * Arg1 + Arg2 * Arg3
	    ADD_SIGNED_EXT          Arg0 * Arg1 + Arg2 * Arg3 - 0.5
	
	where Arg0, Arg1, Arg2 and Arg3 are derived from
	
	    ZERO                    the value 0
	    PRIMARY_COLOR_EXT       primary color of incoming fragment
	    TEXTURE                 texture color of corresponding texture unit
	    CONSTANT_EXT            texture environment constant color
	    PREVIOUS_EXT            result of previous texture environment; on
	                            texture unit 0, this maps to PRIMARY_COLOR_EXT
	    TEXTURE<n>_ARB          texture color of the <n>th texture unit
	
	In addition, the result may be scaled by 1.0, 2.0 or 4.0.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/texture_env_combine4.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texture_env_combine4'
GL_COMBINE4_NV = constant.Constant( 'GL_COMBINE4_NV', 0x8503 )
GL_SOURCE3_RGB_NV = constant.Constant( 'GL_SOURCE3_RGB_NV', 0x8583 )
GL_SOURCE3_ALPHA_NV = constant.Constant( 'GL_SOURCE3_ALPHA_NV', 0x858B )
GL_OPERAND3_RGB_NV = constant.Constant( 'GL_OPERAND3_RGB_NV', 0x8593 )
GL_OPERAND3_ALPHA_NV = constant.Constant( 'GL_OPERAND3_ALPHA_NV', 0x859B )


def glInitTextureEnvCombine4NV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.texture_shader2

Overview (from the spec)
	
	This extension extends the NV_texture_shader functionality to
	support texture shader operations for 3D textures.
	
	See the NV_texture_shader extension for information about the
	texture shader operational model.
	
	The two new texture shader operations are:
	
	<conventional textures>
	
	22.  TEXTURE_3D - Accesses a 3D texture via (s/q,t/q,r/q).
	
	<dot product textures>
	
	23.  DOT_PRODUCT_TEXTURE_3D_NV - When preceded by two DOT_PRODUCT_NV
	     programs in the previous two texture shader stages, computes a
	     third similar dot product and composes the three dot products
	     into (s,t,r) texture coordinate set to access a 3D non-projective
	     texture.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/texture_shader2.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texture_shader2'
GL_DOT_PRODUCT_TEXTURE_3D_NV = constant.Constant( 'GL_DOT_PRODUCT_TEXTURE_3D_NV', 0x86EF )


def glInitTextureShader2NV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension PGI.misc_hints

Overview (from the spec)
	
	The extension allows the app to give various hints regarding 
	desired level of conformance, performance, features, etc.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/PGI/misc_hints.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_PGI_misc_hints'
GL_PREFER_DOUBLEBUFFER_HINT_PGI = constant.Constant( 'GL_PREFER_DOUBLEBUFFER_HINT_PGI', 0x1A1F8 )
GL_CONSERVE_MEMORY_HINT_PGI = constant.Constant( 'GL_CONSERVE_MEMORY_HINT_PGI', 0x1A1FD )
GL_RECLAIM_MEMORY_HINT_PGI = constant.Constant( 'GL_RECLAIM_MEMORY_HINT_PGI', 0x1A1FE )
GL_NATIVE_GRAPHICS_HANDLE_PGI = constant.Constant( 'GL_NATIVE_GRAPHICS_HANDLE_PGI', 0x1A202 )
GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI = constant.Constant( 'GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI', 0x1A203 )
GL_NATIVE_GRAPHICS_END_HINT_PGI = constant.Constant( 'GL_NATIVE_GRAPHICS_END_HINT_PGI', 0x1A204 )
GL_ALWAYS_FAST_HINT_PGI = constant.Constant( 'GL_ALWAYS_FAST_HINT_PGI', 0x1A20C )
GL_ALWAYS_SOFT_HINT_PGI = constant.Constant( 'GL_ALWAYS_SOFT_HINT_PGI', 0x1A20D )
GL_ALLOW_DRAW_OBJ_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_OBJ_HINT_PGI', 0x1A20E )
GL_ALLOW_DRAW_WIN_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_WIN_HINT_PGI', 0x1A20F )
GL_ALLOW_DRAW_FRG_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_FRG_HINT_PGI', 0x1A210 )
GL_ALLOW_DRAW_MEM_HINT_PGI = constant.Constant( 'GL_ALLOW_DRAW_MEM_HINT_PGI', 0x1A211 )
GL_STRICT_DEPTHFUNC_HINT_PGI = constant.Constant( 'GL_STRICT_DEPTHFUNC_HINT_PGI', 0x1A216 )
GL_STRICT_LIGHTING_HINT_PGI = constant.Constant( 'GL_STRICT_LIGHTING_HINT_PGI', 0x1A217 )
GL_STRICT_SCISSOR_HINT_PGI = constant.Constant( 'GL_STRICT_SCISSOR_HINT_PGI', 0x1A218 )
GL_FULL_STIPPLE_HINT_PGI = constant.Constant( 'GL_FULL_STIPPLE_HINT_PGI', 0x1A219 )
GL_CLIP_NEAR_HINT_PGI = constant.Constant( 'GL_CLIP_NEAR_HINT_PGI', 0x1A220 )
GL_CLIP_FAR_HINT_PGI = constant.Constant( 'GL_CLIP_FAR_HINT_PGI', 0x1A221 )
GL_WIDE_LINE_HINT_PGI = constant.Constant( 'GL_WIDE_LINE_HINT_PGI', 0x1A222 )
GL_BACK_NORMALS_HINT_PGI = constant.Constant( 'GL_BACK_NORMALS_HINT_PGI', 0x1A223 )
glHintPGI = platform.createExtensionFunction( 
	'glHintPGI', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint,),
	doc = 'glHintPGI( GLenum(target), GLint(mode) ) -> None',
	argNames = ('target', 'mode',),
)


def glInitMiscHintsPGI():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.vertex_program

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.vertex_program to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.vertex_program import *
### END AUTOGENERATED SECTION
# Note: sizes here are == the only documented sizes I could find,
# may need a lookup table some day...
glGetProgramivARB = wrapper.wrapper(glGetProgramivARB).setOutput(
	'params', (1,),
)
glGetProgramEnvParameterdvARB = wrapper.wrapper(glGetProgramEnvParameterdvARB).setOutput(
	'params',(4,),
)
glGetProgramEnvParameterfvARB = wrapper.wrapper(glGetProgramEnvParameterfvARB).setOutput(
	'params',(4,),
)
glGetProgramLocalParameterdvARB = wrapper.wrapper(glGetProgramLocalParameterdvARB).setOutput(
	'params',(4,),
)
glGetProgramLocalParameterfvARB = wrapper.wrapper(glGetProgramLocalParameterfvARB).setOutput(
	'params',(4,),
)
glGetVertexAttribdvARB = wrapper.wrapper(glGetVertexAttribdvARB).setOutput(
	'params',(1,),
)

##glGetVertexAttribPointervARB = wrapper.wrapper(glGetVertexAttribPointervARB).setOutput(
##	'pointer',(1,),
##)
##
##_base_glGetVertexAttribPointervARB
##def glGetVertexAttribPointervARB( index, pname=GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB ):
##	"""Retrieve named attribute vector
##	
##	XXX Needs logic checking, I don't think I got the number of
##	levels of indirection correct... i.e. I believe it's just going
##	to rewrite the temporary void_p's value, rather than writing
##	into the numpy array.
##	
##	returns 4-element double array...
##	"""
##	output = arrays.GLdoubleArray.zeros( (4,) )
##	pointer = arrays.GLdoubleArray.voidDataPointer( output )
##	_base_glGetVertexAttribPointervARB( index, pname, pointer )
##	return output



"""Load font "constants" (actually void *s) from the GLUT DLL"""
from OpenGL import platform

for name in [
	'GLUT_STROKE_ROMAN',
	'GLUT_STROKE_MONO_ROMAN',
	'GLUT_BITMAP_9_BY_15',
	'GLUT_BITMAP_8_BY_13',
	'GLUT_BITMAP_TIMES_ROMAN_10',
	'GLUT_BITMAP_TIMES_ROMAN_24',
	'GLUT_BITMAP_HELVETICA_10',
	'GLUT_BITMAP_HELVETICA_12',
	'GLUT_BITMAP_HELVETICA_18',
]:
	try:
		# Win32 just has pointers to values 1,2,3,etc
		# GLX has pointers to font structures...
		p = platform.getGLUTFontPointer( name )
	except (ValueError,AttributeError), err:
		print 'GLUT font error', str(err)
	else:
		globals()[name] = p
		del p

del platform, name



'''OpenGL extension ARB.texture_rectangle

Overview (from the spec)
	
	OpenGL texturing is limited to images with power-of-two dimensions
	and an optional 1-texel border.  The ARB_texture_rectangle extension
	adds a new texture target that supports 2D textures without requiring
	power-of-two dimensions.
	
	Non-power-of-two sized (NPOTS) textures are useful for storing video
	images that do not have power-of-two sized (POTS).  Re-sampling
	artifacts are avoided and less texture memory may be required by
	using non-power-of-two sized textures.  Non-power-of-two sized
	textures are also useful for shadow maps and window-space texturing.
	
	However, non-power-of-two sized textures have limitations that
	do not apply to power-of-two sized textures.  NPOTS textures may
	not use mipmap filtering; POTS textures support both mipmapped
	and non-mipmapped filtering.  NPOTS textures support only the
	GL_CLAMP, GL_CLAMP_TO_EDGE, and GL_CLAMP_TO_BORDER wrap modes;
	POTS textures support GL_CLAMP_TO_EDGE, GL_REPEAT, GL_CLAMP,
	GL_MIRRORED_REPEAT, and GL_CLAMP_TO_BORDER (and GL_MIRROR_CLAMP_ATI
	and GL_MIRROR_CLAMP_TO_EDGE_ATI if ATI_texture_mirror_once is
	supported) .  NPOTS textures do not support an optional 1-texel
	border; POTS textures do support an optional 1-texel border.
	
	NPOTS textures are accessed by dimension-dependent (aka
	non-normalized) texture coordinates.  So instead of thinking of
	the texture image lying in a [0..1]x[0..1] range, the NPOTS texture
	image lies in a [0..w]x[0..h] range.
	
	This extension adds a new texture target and related state (proxy,
	binding, max texture size).

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_rectangle.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_rectangle'
GL_TEXTURE_RECTANGLE_ARB = constant.Constant( 'GL_TEXTURE_RECTANGLE_ARB', 0x84F5 )
GL_TEXTURE_BINDING_RECTANGLE_ARB = constant.Constant( 'GL_TEXTURE_BINDING_RECTANGLE_ARB', 0x84F6 )
GL_PROXY_TEXTURE_RECTANGLE_ARB = constant.Constant( 'GL_PROXY_TEXTURE_RECTANGLE_ARB', 0x84F7 )
GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB = constant.Constant( 'GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB', 0x84F8 )


def glInitTextureRectangleARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_3

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_3 to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.VERSION.GL_1_3 import *
### END AUTOGENERATED SECTION
from OpenGL.GL.VERSION.GL_1_3_images import *

for typ,arrayType in (
	('d',arrays.GLdoubleArray),
	('f',arrays.GLfloatArray),
	('i',arrays.GLintArray),
	('s',arrays.GLshortArray),
):
	for size in (1,2,3,4):
		name = 'glMultiTexCoord%(size)s%(typ)sv'%globals()
		globals()[name] = arrays.setInputArraySizeType(
			globals()[name],
			size,
			arrayType, 
			'v',
		)
		del size,name
	del typ,arrayType

for typ,arrayType in (
	('d',arrays.GLdoubleArray),
	('f',arrays.GLfloatArray),
):
	for function in ('glLoadTransposeMatrix','glMultTransposeMatrix'):
		name = '%s%s'%(function,typ)
		globals()[name] = arrays.setInputArraySizeType(
			globals()[name],
			16,
			arrayType, 
			'm',
		)
		del function,name
	del typ,arrayType



'''OpenGL extension SUN.slice_accum

Overview (from the spec)
	
	
	This extension defines a new accumulation operation which enables the accumulation
	buffer to be used for alpha compositing. This enables higher precision alpha
	blending than what can be accomplished using the blend operation.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SUN/slice_accum.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SUN_slice_accum'
GL_SLICE_ACCUM_SUN = constant.Constant( 'GL_SLICE_ACCUM_SUN', 0x85CC )


def glInitSliceAccumSUN():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.fragment_lighting

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SGIX/fragment_lighting.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_fragment_lighting'
GL_FRAGMENT_LIGHTING_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHTING_SGIX', 0x8400 )
GL_FRAGMENT_COLOR_MATERIAL_SGIX = constant.Constant( 'GL_FRAGMENT_COLOR_MATERIAL_SGIX', 0x8401 )
GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX = constant.Constant( 'GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX', 0x8402 )
GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX = constant.Constant( 'GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX', 0x8403 )
GL_MAX_FRAGMENT_LIGHTS_SGIX = constant.Constant( 'GL_MAX_FRAGMENT_LIGHTS_SGIX', 0x8404 )
GL_MAX_ACTIVE_LIGHTS_SGIX = constant.Constant( 'GL_MAX_ACTIVE_LIGHTS_SGIX', 0x8405 )
GL_CURRENT_RASTER_NORMAL_SGIX = constant.Constant( 'GL_CURRENT_RASTER_NORMAL_SGIX', 0x8406 )
GL_LIGHT_ENV_MODE_SGIX = constant.Constant( 'GL_LIGHT_ENV_MODE_SGIX', 0x8407 )
GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX', 0x8408 )
GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX', 0x8409 )
GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX', 0x840A )
GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX', 0x840B )
GL_FRAGMENT_LIGHT0_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT0_SGIX', 0x840C )
GL_FRAGMENT_LIGHT1_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT1_SGIX', 0x840D )
GL_FRAGMENT_LIGHT2_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT2_SGIX', 0x840E )
GL_FRAGMENT_LIGHT3_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT3_SGIX', 0x840F )
GL_FRAGMENT_LIGHT4_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT4_SGIX', 0x8410 )
GL_FRAGMENT_LIGHT5_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT5_SGIX', 0x8411 )
GL_FRAGMENT_LIGHT6_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT6_SGIX', 0x8412 )
GL_FRAGMENT_LIGHT7_SGIX = constant.Constant( 'GL_FRAGMENT_LIGHT7_SGIX', 0x8413 )
glFragmentColorMaterialSGIX = platform.createExtensionFunction( 
	'glFragmentColorMaterialSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum,),
	doc = 'glFragmentColorMaterialSGIX( GLenum(face), GLenum(mode) ) -> None',
	argNames = ('face', 'mode',),
)

glFragmentLightfSGIX = platform.createExtensionFunction( 
	'glFragmentLightfSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLfloat,),
	doc = 'glFragmentLightfSGIX( GLenum(light), GLenum(pname), GLfloat(param) ) -> None',
	argNames = ('light', 'pname', 'param',),
)

glFragmentLightfvSGIX = platform.createExtensionFunction( 
	'glFragmentLightfvSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glFragmentLightfvSGIX( GLenum(light), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('light', 'pname', 'params',),
)

glFragmentLightiSGIX = platform.createExtensionFunction( 
	'glFragmentLightiSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint,),
	doc = 'glFragmentLightiSGIX( GLenum(light), GLenum(pname), GLint(param) ) -> None',
	argNames = ('light', 'pname', 'param',),
)

glFragmentLightivSGIX = platform.createExtensionFunction( 
	'glFragmentLightivSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glFragmentLightivSGIX( GLenum(light), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('light', 'pname', 'params',),
)

glFragmentLightModelfSGIX = platform.createExtensionFunction( 
	'glFragmentLightModelfSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat,),
	doc = 'glFragmentLightModelfSGIX( GLenum(pname), GLfloat(param) ) -> None',
	argNames = ('pname', 'param',),
)

glFragmentLightModelfvSGIX = platform.createExtensionFunction( 
	'glFragmentLightModelfvSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glFragmentLightModelfvSGIX( GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('pname', 'params',),
)

glFragmentLightModeliSGIX = platform.createExtensionFunction( 
	'glFragmentLightModeliSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint,),
	doc = 'glFragmentLightModeliSGIX( GLenum(pname), GLint(param) ) -> None',
	argNames = ('pname', 'param',),
)

glFragmentLightModelivSGIX = platform.createExtensionFunction( 
	'glFragmentLightModelivSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glFragmentLightModelivSGIX( GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('pname', 'params',),
)

glFragmentMaterialfSGIX = platform.createExtensionFunction( 
	'glFragmentMaterialfSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLfloat,),
	doc = 'glFragmentMaterialfSGIX( GLenum(face), GLenum(pname), GLfloat(param) ) -> None',
	argNames = ('face', 'pname', 'param',),
)

glFragmentMaterialfvSGIX = platform.createExtensionFunction( 
	'glFragmentMaterialfvSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glFragmentMaterialfvSGIX( GLenum(face), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('face', 'pname', 'params',),
)

glFragmentMaterialiSGIX = platform.createExtensionFunction( 
	'glFragmentMaterialiSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLint,),
	doc = 'glFragmentMaterialiSGIX( GLenum(face), GLenum(pname), GLint(param) ) -> None',
	argNames = ('face', 'pname', 'param',),
)

glFragmentMaterialivSGIX = platform.createExtensionFunction( 
	'glFragmentMaterialivSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glFragmentMaterialivSGIX( GLenum(face), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('face', 'pname', 'params',),
)

glGetFragmentLightfvSGIX = platform.createExtensionFunction( 
	'glGetFragmentLightfvSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetFragmentLightfvSGIX( GLenum(light), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('light', 'pname', 'params',),
)

glGetFragmentLightivSGIX = platform.createExtensionFunction( 
	'glGetFragmentLightivSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetFragmentLightivSGIX( GLenum(light), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('light', 'pname', 'params',),
)

glGetFragmentMaterialfvSGIX = platform.createExtensionFunction( 
	'glGetFragmentMaterialfvSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetFragmentMaterialfvSGIX( GLenum(face), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('face', 'pname', 'params',),
)

glGetFragmentMaterialivSGIX = platform.createExtensionFunction( 
	'glGetFragmentMaterialivSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetFragmentMaterialivSGIX( GLenum(face), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('face', 'pname', 'params',),
)

glLightEnviSGIX = platform.createExtensionFunction( 
	'glLightEnviSGIX', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint,),
	doc = 'glLightEnviSGIX( GLenum(pname), GLint(param) ) -> None',
	argNames = ('pname', 'param',),
)


def glInitFragmentLightingSGIX():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )
